@@ -57,6 +57,7 @@
 #include <visp3/gui/vpDisplayGTK.h>
 #include <visp3/gui/vpDisplayOpenCV.h>
 #include <visp3/gui/vpDisplayX.h>
+#include <visp3/gui/vpPlot.h>
 #include <visp3/io/vpImageIo.h>
 #include <visp3/io/vpParseArgv.h>
 #include <visp3/robot/vpSimulatorCamera.h>
@@ -64,11 +65,10 @@
 #include <visp3/visual_features/vpFeatureBuilder.h>
 #include <visp3/vs/vpServo.h>
 
-#define GETOPTARGS "dh"
+#define GETOPTARGS "dhp"
 
-#ifdef VISP_HAVE_DISPLAY
-void usage(const char *name, const char *badparam);
-bool getOptions(int argc, const char **argv, bool &display);
+#if defined(VISP_HAVE_DISPLAY) \
+  && (defined(VISP_HAVE_LAPACK) || defined(VISP_HAVE_EIGEN3) || defined(VISP_HAVE_OPENCV))
 
 /*!
 
@@ -96,13 +96,16 @@ at a given distance from the world frame. In fact the object trajectory \n\
 is on a sphere whose center is the origin of the world frame.\n\
           \n\
 SYNOPSIS\n\
-  %s [-d] [-h]\n", name);
+  %s [-d] [-p] [-h]\n", name);
 
   fprintf(stdout, "\n\
 OPTIONS:                                          \n\
   -d \n\
      Turn off the display.\n\
             \n\
+  -p \n\
+     Turn off the plotter.\n\
+                            \n\
   -h\n\
      Print the help.\n");
 
@@ -117,11 +120,12 @@ OPTIONS:                                          \n\
   \param argc : Command line number of parameters.
   \param argv : Array of command line parameters.
   \param display : Display activation.
+  \param plot : Plotter activation.
 
   \return false if the program has to be stopped, true otherwise.
 
 */
-bool getOptions(int argc, const char **argv, bool &display)
+bool getOptions(int argc, const char **argv, bool &display, bool &plot)
 {
   const char *optarg_;
   int c;
@@ -131,15 +135,16 @@ bool getOptions(int argc, const char **argv, bool &display)
     case 'd':
       display = false;
       break;
+    case 'p':
+      plot = false;
+      break;
     case 'h':
       usage(argv[0], NULL);
       return false;
-      break;
 
     default:
       usage(argv[0], optarg_);
       return false;
-      break;
     }
   }
 
@@ -158,9 +163,10 @@ int main(int argc, const char **argv)
 {
   try {
     bool opt_display = true;
+    bool opt_plot = true;
 
     // Read the command line options
-    if (getOptions(argc, argv, opt_display) == false) {
+    if (getOptions(argc, argv, opt_display, opt_plot) == false) {
       exit(-1);
     }
 
@@ -184,16 +190,18 @@ int main(int argc, const char **argv)
       display[0].init(Iint, 100, 100, "The internal view");
       display[1].init(Iext, 100, 100, "The first external view");
       vpDisplay::setWindowPosition(Iint, 0, 0);
-      vpDisplay::setWindowPosition(Iext, 700, 0);
+      vpDisplay::setWindowPosition(Iext, 750, 0);
       vpDisplay::display(Iint);
       vpDisplay::flush(Iint);
       vpDisplay::display(Iext);
       vpDisplay::flush(Iext);
     }
 
+    vpPlot *plotter = NULL;
+
     vpServo task;
     vpSimulatorCamera robot;
-    float sampling_time = 0.040f; // Sampling period in second
+    float sampling_time = 0.020f; // Sampling period in second
     robot.setSamplingTime(sampling_time);
 
     // Set initial position of the object in the camera frame
@@ -238,6 +246,24 @@ int main(int argc, const char **argv)
     for (int i = 0; i < 2; i++)
       task.addFeature(l[i], ld[i]);
 
+    if (opt_plot) {
+      plotter = new vpPlot(2, 480, 640, 750, 550, "Real time curves plotter");
+      plotter->setTitle(0, "Visual features error");
+      plotter->setTitle(1, "Camera velocities");
+      plotter->initGraph(0, task.getDimension());
+      plotter->initGraph(1, 6);
+      plotter->setLegend(0, 0, "error_feat_l1_rho");
+      plotter->setLegend(0, 1, "error_feat_l1_theta");
+      plotter->setLegend(0, 2, "error_feat_l2_rho");
+      plotter->setLegend(0, 3, "error_feat_l2_theta");
+      plotter->setLegend(1, 0, "vc_x");
+      plotter->setLegend(1, 1, "vc_y");
+      plotter->setLegend(1, 2, "vc_z");
+      plotter->setLegend(1, 3, "wc_x");
+      plotter->setLegend(1, 4, "wc_y");
+      plotter->setLegend(1, 5, "wc_z");
+    }
+
     task.setLambda(1);
 
     vpWireFrameSimulator sim;
@@ -259,10 +285,10 @@ int main(int argc, const char **argv)
     sim.setInternalCameraParameters(camera);
     sim.setExternalCameraParameters(camera);
 
-    int stop = 10;
+    int max_iter = 10;
 
     if (opt_display) {
-      stop = 2500;
+      max_iter = 2500;
 
       // Get the internal and external views
       sim.getInternalImage(Iint);
@@ -278,6 +304,8 @@ int main(int argc, const char **argv)
       vpDisplay::displayFrame(Iext, camMf * sim.get_fMo(), camera, 0.2, vpColor::none);
       vpDisplay::displayFrame(Iext, camMf, camera, 0.2, vpColor::none);
 
+      vpDisplay::displayText(Iint, 20, 20, "Click to start visual servo", vpColor::red);
+
       vpDisplay::flush(Iint);
       vpDisplay::flush(Iext);
 
@@ -292,28 +320,29 @@ int main(int argc, const char **argv)
     task.print();
 
     int iter = 0;
+    bool stop = false;
     vpColVector v;
 
     // Set the secondary task parameters
-    vpColVector e1(6);
-    e1 = 0;
-    vpColVector e2(6);
-    e2 = 0;
+    vpColVector e1(6, 0);
+    vpColVector e2(6, 0);
     vpColVector proj_e1;
     vpColVector proj_e2;
-    iter = 0;
     double rapport = 0;
     double vitesse = 0.3;
     int tempo = 600;
 
-    while (iter++ < stop) {
+    double t_prev, t = vpTime::measureTimeMs();
+
+    while (iter++ < max_iter && !stop) {
+      t_prev = t;
+      t = vpTime::measureTimeMs();
+
       if (opt_display) {
         vpDisplay::display(Iint);
         vpDisplay::display(Iext);
       }
 
-      double t = vpTime::measureTimeMs();
-
       robot.get_eJe(eJe);
       task.set_eJe(eJe);
 
@@ -330,34 +359,34 @@ int main(int argc, const char **argv)
       if (iter % tempo < 200 && iter % tempo >= 0) {
         e2 = 0;
         e1[0] = -fabs(vitesse);
-        proj_e1 = task.secondaryTask(e1);
+        proj_e1 = task.secondaryTask(e1, true);
         rapport = -vitesse / proj_e1[0];
         proj_e1 *= rapport;
         v += proj_e1;
       }
 
-      if (iter % tempo < 300 && iter % tempo >= 200) {
+      else if (iter % tempo < 300 && iter % tempo >= 200) {
         e1 = 0;
         e2[1] = -fabs(vitesse);
-        proj_e2 = task.secondaryTask(e2);
+        proj_e2 = task.secondaryTask(e2, true);
         rapport = -vitesse / proj_e2[1];
         proj_e2 *= rapport;
         v += proj_e2;
       }
 
-      if (iter % tempo < 500 && iter % tempo >= 300) {
+      else if (iter % tempo < 500 && iter % tempo >= 300) {
         e2 = 0;
         e1[0] = -fabs(vitesse);
-        proj_e1 = task.secondaryTask(e1);
+        proj_e1 = task.secondaryTask(e1, true);
         rapport = vitesse / proj_e1[0];
         proj_e1 *= rapport;
         v += proj_e1;
       }
 
-      if (iter % tempo < 600 && iter % tempo >= 500) {
+      else if (iter % tempo < 600 && iter % tempo >= 500) {
         e1 = 0;
         e2[1] = -fabs(vitesse);
-        proj_e2 = task.secondaryTask(e2);
+        proj_e2 = task.secondaryTask(e2, true);
         rapport = vitesse / proj_e2[1];
         proj_e2 *= rapport;
         v += proj_e2;
@@ -370,6 +399,11 @@ int main(int argc, const char **argv)
                         // doesn't move
       sim.setCameraPositionRelObj(cMo);
 
+      if (opt_plot) {
+        plotter->plot(0, iter, task.getError());
+        plotter->plot(1, iter, v);
+      }
+
       if (opt_display) {
         // Get the internal and external views
         sim.getInternalImage(Iint);
@@ -385,19 +419,41 @@ int main(int argc, const char **argv)
                                 vpColor::none);
         vpDisplay::displayFrame(Iext, sim.getExternalCameraPosition() * sim.get_fMo(), camera, 0.2, vpColor::none);
         vpDisplay::displayFrame(Iext, sim.getExternalCameraPosition(), camera, 0.2, vpColor::none);
-        ;
 
-        vpDisplay::flush(Iint);
+        vpDisplay::displayText(Iint, 20, 20, "Click to stop visual servo", vpColor::red);
+
+        std::stringstream ss;
+        ss << "Loop time: " << t - t_prev << " ms";
+        vpDisplay::displayText(Iint, 40, 20, ss.str(), vpColor::red);
+
+        if (vpDisplay::getClick(Iint, false)) {
+          stop = true;
+        }
+
         vpDisplay::flush(Iext);
-      }
+        vpDisplay::flush(Iint);
 
-      vpTime::wait(t, sampling_time * 1000); // Wait 40 ms
+        vpTime::wait(t, sampling_time * 1000); // Wait ms
+      }
 
       std::cout << "|| s - s* || = " << (task.getError()).sumSquare() << std::endl;
     }
 
+    if (opt_plot && plotter != NULL) {
+      vpDisplay::display(Iint);
+      sim.getInternalImage(Iint);
+      vpDisplay::displayFrame(Iint, cMo, camera, 0.2, vpColor::none);
+      vpDisplay::displayFrame(Iint, cdMo, camera, 0.2, vpColor::none);
+      vpDisplay::displayText(Iint, 20, 20, "Click to quit", vpColor::red);
+      if (vpDisplay::getClick(Iint)) {
+        stop = true;
+      }
+      vpDisplay::flush(Iint);
+
+      delete plotter;
+    }
+
     task.print();
-    task.kill();
 
     return EXIT_SUCCESS;
   } catch (const vpException &e) {
@@ -405,6 +461,12 @@ int main(int argc, const char **argv)
     return EXIT_FAILURE;
   }
 }
+#elif !(defined(VISP_HAVE_LAPACK) || defined(VISP_HAVE_EIGEN3) || defined(VISP_HAVE_OPENCV))
+int main()
+{
+  std::cout << "Cannot run this example: install Lapack, Eigen3 or OpenCV" << std::endl;
+  return EXIT_SUCCESS;
+}
 #else
 int main()
 {
