@@ -50,7 +50,8 @@
 #include <visp3/core/vpConfig.h>
 #include <visp3/core/vpDebug.h>
 
-#if (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV))
+#if (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV)) \
+  && (defined(VISP_HAVE_LAPACK) || defined(VISP_HAVE_EIGEN3) || defined(VISP_HAVE_OPENCV))
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -79,7 +80,7 @@ bool getOptions(int argc, const char **argv, bool &click_allowed, bool &display)
 
 /*!
 
-Print the program options.
+  Print the program options.
 
   \param name : Program name.
   \param badparam : Bad parameter name.
@@ -115,7 +116,7 @@ OPTIONS:                                               Default\n\
 
 /*!
 
-Set the program options.
+  Set the program options.
 
   \param argc : Command line number of parameters.
   \param argv : Array of command line parameters.
@@ -140,12 +141,10 @@ bool getOptions(int argc, const char **argv, bool &click_allowed, bool &display)
     case 'h':
       usage(argv[0], NULL);
       return false;
-      break;
 
     default:
       usage(argv[0], optarg_);
       return false;
-      break;
     }
   }
 
@@ -231,8 +230,7 @@ int main(int argc, const char **argv)
     cylinder.print();
 
     vpFeatureLine ld[2];
-    int i;
-    for (i = 0; i < 2; i++)
+    for (unsigned int i = 0; i < 2; i++)
       vpFeatureBuilder::create(ld[i], cylinder, i);
 
     // computes  the cylinder coordinates in the camera frame and its 2D
@@ -241,7 +239,7 @@ int main(int argc, const char **argv)
     cylinder.print();
 
     vpFeatureLine l[2];
-    for (i = 0; i < 2; i++) {
+    for (unsigned int i = 0; i < 2; i++) {
       vpFeatureBuilder::create(l[i], cylinder, i);
       l[i].print();
     }
@@ -295,7 +293,7 @@ int main(int argc, const char **argv)
       // retrieve x,y and Z of the vpLine structure
       cylinder.track(cMo);
       //    cylinder.print() ;
-      for (i = 0; i < 2; i++) {
+      for (unsigned int i = 0; i < 2; i++) {
         vpFeatureBuilder::create(l[i], cylinder, i);
         //   l[i].print() ;
       }
@@ -313,19 +311,18 @@ int main(int argc, const char **argv)
       robot.setVelocity(vpRobot::CAMERA_FRAME, v);
 
       std::cout << "|| s - s* || = " << (task.getError()).sumSquare() << std::endl;
-      ;
 
       //   vpDisplay::getClick(I) ;
     } while ((task.getError()).sumSquare() > 1e-9);
 
     if (opt_display && opt_click_allowed) {
-      std::cout << "\nClick in the camera view window to end..." << std::endl;
+      vpDisplay::displayText(I, 20, 20, "Click to quit...", vpColor::black);
+      vpDisplay::flush(I);
       vpDisplay::getClick(I);
     }
 
     // Display task information
     task.print();
-    task.kill();
     return EXIT_SUCCESS;
   } catch (const vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
@@ -333,10 +330,16 @@ int main(int argc, const char **argv)
   }
 }
 
+#elif !(defined(VISP_HAVE_LAPACK) || defined(VISP_HAVE_EIGEN3) || defined(VISP_HAVE_OPENCV))
+int main()
+{
+  std::cout << "Cannot run this example: install Lapack, Eigen3 or OpenCV" << std::endl;
+  return EXIT_SUCCESS;
+}
 #else
 int main()
 {
-  std::cout << "You do not have X11, or GTK, or GDI (Graphical Device Interface) functionalities to display images..." << std::endl;
+  std::cout << "You do not have X11, or GTK, or GDI (Graphical Device Interface) or OpenCV functionalities to display images..." << std::endl;
   std::cout << "Tip if you are on a unix-like system:" << std::endl;
   std::cout << "- Install X11, configure again ViSP using cmake and build again this example" << std::endl;
   std::cout << "Tip if you are on a windows-like system:" << std::endl;
