@@ -48,7 +48,8 @@
 #include <visp3/core/vpConfig.h>
 #include <visp3/core/vpDebug.h>
 
-#if (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV))
+#if (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GTK) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV)) \
+  && (defined(VISP_HAVE_LAPACK) || defined(VISP_HAVE_EIGEN3) || defined(VISP_HAVE_OPENCV))
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -77,7 +78,7 @@ bool getOptions(int argc, const char **argv, bool &click_allowed, bool &display)
 
 /*!
 
-Print the program options.
+  Print the program options.
 
   \param name : Program name.
   \param badparam : Bad parameter name.
@@ -113,7 +114,7 @@ OPTIONS:                                               Default\n\
 
 /*!
 
-Set the program options.
+  Set the program options.
 
   \param argc : Command line number of parameters.
   \param argv : Array of command line parameters.
@@ -139,12 +140,10 @@ bool getOptions(int argc, const char **argv, bool &click_allowed, bool &display)
     case 'h':
       usage(argv[0], NULL);
       return false;
-      break;
 
     default:
       usage(argv[0], optarg_);
       return false;
-      break;
     }
   }
 
@@ -200,10 +199,8 @@ int main(int argc, const char **argv)
       }
     }
 
-    double px, py;
-    px = py = 600;
-    double u0, v0;
-    u0 = v0 = 256;
+    double px = 500, py = 500;
+    double u0 = 150, v0 = 160;
 
     vpCameraParameters cam(px, py, u0, v0);
 
@@ -306,13 +303,13 @@ int main(int argc, const char **argv)
     }
 
     if (opt_display && opt_click_allowed) {
-      std::cout << "\nClick in the camera view window to end..." << std::endl;
+      vpDisplay::displayText(I, 20, 20, "Click to quit...", vpColor::white);
+      vpDisplay::flush(I);
       vpDisplay::getClick(I);
     }
 
     // Display task information
     task.print();
-    task.kill();
     return EXIT_SUCCESS;
   } catch (const vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
@@ -320,6 +317,12 @@ int main(int argc, const char **argv)
   }
 }
 
+#elif !(defined(VISP_HAVE_LAPACK) || defined(VISP_HAVE_EIGEN3) || defined(VISP_HAVE_OPENCV))
+int main()
+{
+  std::cout << "Cannot run this example: install Lapack, Eigen3 or OpenCV" << std::endl;
+  return EXIT_SUCCESS;
+}
 #else
 int main()
 {
