@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -242,17 +242,17 @@ int main(int argc, const char **argv)
     sleep(5);
 
     std::cout << "The end" << std::endl;
-    return 0;
-  } catch (vpException &e) {
+    return EXIT_SUCCESS;
+  } catch (const vpException &e) {
     std::cout << "Catch a ViSP exception: " << e << std::endl;
-    return 1;
+    return EXIT_FAILURE;
   }
 }
 #else
 int main()
 {
-  vpERROR_TRACE("You do not have an afma4 robot connected to your computer...");
-  return 0;
+  std::cout << "You do not have an afma4 robot connected to your computer..." << std::endl;
+  return EXIT_SUCCESS;
 }
 
 #endif
