@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,23 +39,23 @@
 
 #include <visp3/core/vpConfig.h>
 
+#include <visp3/robot/vpRobotPioneer.h> // Include first to avoid build issues with Status, None, isfinite
 #include <visp3/blob/vpDot2.h>
 #include <visp3/core/vpCameraParameters.h>
 #include <visp3/core/vpHomogeneousMatrix.h>
 #include <visp3/core/vpImage.h>
 #include <visp3/core/vpVelocityTwistMatrix.h>
 #include <visp3/gui/vpDisplayGDI.h>
-#include <visp3/gui/vpDisplayX.h>
 #include <visp3/gui/vpPlot.h>
 #include <visp3/robot/vpPioneerPan.h>
 #include <visp3/robot/vpRobotBiclops.h>
-#include <visp3/robot/vpRobotPioneer.h> // Include before vpDisplayX to avoid build issues
 #include <visp3/sensor/vp1394CMUGrabber.h>
 #include <visp3/sensor/vp1394TwoGrabber.h>
 #include <visp3/sensor/vpV4l2Grabber.h>
 #include <visp3/visual_features/vpFeatureBuilder.h>
 #include <visp3/visual_features/vpFeatureSegment.h>
 #include <visp3/vs/vpServo.h>
+#include <visp3/gui/vpDisplayX.h> // Should be included after vpRobotPioneer.h
 
 #define USE_REAL_ROBOT
 #define USE_PLOTTER
@@ -413,10 +413,10 @@ int main(int argc, char **argv)
 
     // Kill the servo task
     task.print();
-    task.kill();
-  } catch (vpException &e) {
+    return EXIT_SUCCESS;
+  } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
-    return 1;
+    return EXIT_FAILURE;
   }
 #endif
 #endif
@@ -425,6 +425,6 @@ int main(int argc, char **argv)
 int main()
 {
   std::cout << "ViSP is not able to control the Pioneer robot" << std::endl;
-  return 0;
+  return EXIT_SUCCESS;
 }
 #endif
