@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -117,17 +117,18 @@ int main()
     vpCTRACE << "Set articular frame velocity " << qdot.t();
     robot.setVelocity(vpRobot::ARTICULAR_FRAME, qdot);
     sleep(2);
-  } catch (...) {
-    std::cout << "Sorry PtU46 not available ..." << std::endl;
   }
-
-  return 0;
+  catch (const vpException &e) {
+    std::cout << "Sorry PtU46 not available. Got exception: " << e << std::endl;
+    return EXIT_FAILURE
+  }
+  return EXIT_SUCCESS;
 }
 #else
 int main()
 {
-  vpERROR_TRACE("You do not have a ptu-46 robot connected to your computer...");
-  return 0;
+  std::cout << "You do not have an PTU46 PT robot connected to your computer..." << std::endl;
+  return EXIT_SUCCESS;
 }
 
 #endif
