@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -77,12 +77,12 @@ int main()
   int myvalue;
   std::cin >> myvalue;
 
-  return 0;
+  return EXIT_SUCCESS;
 }
 #else
 int main()
 {
-  vpTRACE("Sorry, for the moment, vpKeyboard class works only on unix...");
-  return 0;
+  std::cout << "vpKeyboard class works only on unix..." << std::endl;
+  return EXIT_SUCCESS;
 }
 #endif
