@@ -43,7 +43,8 @@
 #include <iostream>
 #include <visp3/core/vpConfig.h>
 
-#if defined(VISP_HAVE_MODULE_MBT) && defined(VISP_HAVE_DISPLAY)
+#if (defined(VISP_HAVE_MODULE_MBT) && defined(VISP_HAVE_DISPLAY)) \
+  && (defined(VISP_HAVE_LAPACK) || defined(VISP_HAVE_EIGEN3) || defined(VISP_HAVE_OPENCV))
 
 #include <visp3/core/vpDebug.h>
 #include <visp3/core/vpHomogeneousMatrix.h>
@@ -330,12 +331,12 @@ bool read_data(unsigned int cpt, const std::string &input_directory, vpImage<uns
 }
 
 void loadConfiguration(vpMbTracker *const tracker, const std::string &
-#if defined(VISP_HAVE_PUGIXML) && USE_XML
+#if USE_XML
                        configFile_depth
 #endif
 )
 {
-#if defined(VISP_HAVE_PUGIXML) && USE_XML
+#if USE_XML
   // From the xml file
   dynamic_cast<vpMbGenericTracker *>(tracker)->loadConfigFile(configFile_depth);
 #else
@@ -760,13 +761,6 @@ int main(int argc, const char **argv)
     delete tracker;
     tracker = NULL;
 
-#if defined(VISP_HAVE_COIN3D) && (COIN_MAJOR_VERSION >= 2)
-    // Cleanup memory allocated by Coin library used to load a vrml model in
-    // vpMbGenericTracker::loadModel() We clean only if Coin was used.
-    if (use_vrml)
-      SoDB::finish();
-#endif
-
     return EXIT_SUCCESS;
   } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
@@ -774,12 +768,17 @@ int main(int argc, const char **argv)
   }
 }
 
-#else
+#elif !(defined(VISP_HAVE_MODULE_MBT) && defined(VISP_HAVE_DISPLAY))
 int main()
 {
-  std::cerr << "visp_mbt, visp_gui modules and OpenCV are required to run "
-               "this example."
+  std::cout << "Cannot run this example: visp_mbt, visp_gui modules are required."
             << std::endl;
   return EXIT_SUCCESS;
 }
+#else
+int main()
+{
+  std::cout << "Cannot run this example: install Lapack, Eigen3 or OpenCV" << std::endl;
+  return EXIT_SUCCESS;
+}
 #endif
