@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -502,10 +502,10 @@ int main(int argc, const char **argv)
       vpDisplay::getClick(I);
     }
 
-    return 0;
-  } catch (vpException &e) {
+    return EXIT_SUCCESS;
+  } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
-    return 1;
+    return EXIT_FAILURE;
   }
 }
 #else
@@ -516,6 +516,7 @@ int main()
   std::cout << "visp_me module or X11, GTK, GDI or OpenCV display "
                "functionalities are required..."
             << std::endl;
+  return EXIT_SUCCESS;
 }
 
 #endif
