@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -258,6 +258,10 @@ int main(int argc, const char **argv)
     reader.setFirstFrameIndex(opt_first);
     reader.open(I);
     std::cout << "Current image number: " << reader.getFrameIndex() << std::endl;
+    if ((opt_first) != reader.getFrameIndex()) {
+      std::cout << "Unable to get requested image number: " << opt_first << std::endl;
+      return EXIT_FAILURE;
+    }
 
 // We open a window using either X11, GTK, GDI or OpenCV.
 #if defined VISP_HAVE_X11
@@ -284,6 +288,10 @@ int main(int argc, const char **argv)
 
     reader.getFrame(I, opt_first + 1);
     std::cout << "Current image number (should be " << opt_first + 1 << "): " << reader.getFrameIndex() << std::endl;
+    if ((opt_first + 1) != reader.getFrameIndex()) {
+      std::cout << "Unable to get requested image number: " << opt_first + 1 << std::endl;
+      return EXIT_FAILURE;
+    }
 
     if (opt_display) {
       vpDisplay::display(I);
@@ -325,16 +333,16 @@ int main(int argc, const char **argv)
       vpDisplay::getClick(I);
     }
 
-    return 0;
-  } catch (vpException &e) {
+    return EXIT_SUCCESS;
+  } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
-    return 1;
+    return EXIT_FAILURE;
   }
 }
 #else
 int main()
 {
   std::cout << "Sorry, no display is available. We quit this example." << std::endl;
-  return 0;
+  return EXIT_SUCCESS;
 }
 #endif
