@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -246,10 +246,12 @@ void vpAROgre::init(bool
   }
   std::cout << "######################### Load plugin file: " << pluginFile << std::endl;
 
-  if (Ogre::Root::getSingletonPtr() == NULL)
+  if (Ogre::Root::getSingletonPtr() == NULL) {
     mRoot = new Ogre::Root(pluginFile, "ogre.cfg", "Ogre.log");
-  else
+  }
+  else {
     mRoot = Ogre::Root::getSingletonPtr();
+  }
 
   // Load resource paths from config file
 
@@ -311,18 +313,21 @@ void vpAROgre::init(bool
   bool canInit = true;
   if (mshowConfigDialog) {
     mRoot->restoreConfig();
-    if (!mRoot->showConfigDialog())
+    if (!mRoot->showConfigDialog()) {
       canInit = false;
+    }
   } else {
-    if (!mRoot->restoreConfig())
+    if (!mRoot->restoreConfig()) {
       canInit = false;
+    }
   }
 
   if (!mRoot->isInitialised()) {
     if (!canInit) { // We set the default renderer system
       const Ogre::RenderSystemList &lRenderSystemList = mRoot->getAvailableRenderers();
-      if (lRenderSystemList.size() == 0)
+      if (lRenderSystemList.size() == 0) {
         throw "ConfigDialog aborted"; // Exit the application on cancel
+      }
 
       Ogre::RenderSystem *lRenderSystem = lRenderSystemList.at(0);
       std::cout << "Using " << lRenderSystem->getName() << " as renderer." << std::endl;
@@ -346,21 +351,20 @@ void vpAROgre::init(bool
         std::stringstream ss(rightconf.c_str());
         std::string dummy;
         ss >> mWindowWidth >> dummy >> mWindowHeight;
-        if (ss.fail())
+        if (ss.fail()) {
           std::cout << "Cannot read Ogre video mode" << std::endl;
-      } else {
-        if (mWindowWidth == 0 && mWindowHeight == 0) {
-          mWindowWidth = mBackgroundWidth;
-          mWindowHeight = mBackgroundHeight;
         }
+      } else if (mWindowWidth == 0 && mWindowHeight == 0) {
+        mWindowWidth = mBackgroundWidth;
+        mWindowHeight = mBackgroundHeight;
       }
     } else if (leftconf == "Full Screen") {
-      if (canInit) {
-        if (rightconf == "Yes")
-          fullscreen = true;
+      if (canInit && (rightconf == "Yes")) {
+        fullscreen = true;
       }
-    } else
+    } else {
       misc[leftconf] = rightconf;
+    }
 
     ++it;
   }
@@ -428,8 +432,9 @@ void vpAROgre::init(bool
   // Create all devices
   // Here we only consider the keyboard input
   mKeyboard = static_cast<OIS::Keyboard *>(mInputManager->createInputObject(OIS::OISKeyboard, bufferedKeys));
-  if (!bufferedKeys)
+  if (!bufferedKeys) {
     mKeyboard->setEventCallback(this);
+  }
 #endif
 
   // Initialise a render to texture to be able to retrieve a screenshot
@@ -464,10 +469,8 @@ vpAROgre::~vpAROgre(void)
   }
 
   // Delete root
-  if (Ogre::Root::getSingletonPtr() && !Ogre::Root::getSingletonPtr()->getSceneManagerIterator().hasMoreElements()) {
-    if (mRoot) {
-      delete mRoot;
-    }
+  if (Ogre::Root::getSingletonPtr() && !Ogre::Root::getSingletonPtr()->getSceneManagerIterator().hasMoreElements() && mRoot) {
+    delete mRoot;
   }
   mRoot = 0;
 }
@@ -482,8 +485,10 @@ bool vpAROgre::stopTest(const Ogre::FrameEvent &evt)
   // Always keep this part
   if (keepOn) {
     return updateScene(evt);
-  } else
+  }
+  else {
     return keepOn;
+  }
 }
 
 /*!
@@ -756,7 +761,7 @@ void vpAROgre::setVisibility(const std::string &sceneName, bool isVisible)
   \param factory : Scale factor along the x-axis.
   \param factorz : Scale factor along the x-axis.
 */
-void vpAROgre::setScale(const std::string &sceneName, const float factorx, const float factory, const float factorz)
+void vpAROgre::setScale(const std::string &sceneName, float factorx, float factory, float factorz)
 {
   // Reset the scale to its original value
   mSceneMgr->getSceneNode(sceneName)->scale(Ogre::Vector3(1, 1, 1) / mSceneMgr->getSceneNode(sceneName)->getScale());
@@ -1049,7 +1054,7 @@ void vpAROgre::getRenderingOutput(vpImage<vpRGBa> &I, const vpHomogeneousMatrix
   if (I.getHeight() != mWindow->getHeight() || I.getWidth() != mWindow->getWidth()) {
     I.resize(mWindow->getHeight(), mWindow->getWidth());
   }
-  Ogre::HardwarePixelBufferSharedPtr mPixelBuffer = dynTexPtr->getBuffer();
+  mPixelBuffer = dynTexPtr->getBuffer();
   mPixelBuffer->lock(Ogre::HardwareBuffer::HBL_DISCARD);
   const Ogre::PixelBox &pixelBox = mPixelBuffer->getCurrentLock();
   dynTexPtr->getBuffer()->blitToMemory(pixelBox);
