@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -48,8 +48,8 @@
  *
  *****************************************************************************/
 
-#ifndef __VP_DEBUG_HH
-#define __VP_DEBUG_HH
+#ifndef _vpDebug_h_
+#define _vpDebug_h_
 
 #include <iostream>
 #include <stdarg.h>
