@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -49,6 +49,7 @@
 #include <visp3/core/vpImageException.h>
 #include <visp3/core/vpMath.h>
 #include <visp3/core/vpMatrix.h>
+#include <visp3/core/vpRGBa.h>
 
 #include <fstream>
 #include <iostream>
@@ -67,8 +68,8 @@ class VISP_EXPORT vpImageFilter
 {
 public:
 #if defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100)
-  static void canny(const vpImage<unsigned char> &I, vpImage<unsigned char> &Ic, const unsigned int gaussianFilterSize,
-                    const double thresholdCanny, const unsigned int apertureSobel);
+  static void canny(const vpImage<unsigned char> &I, vpImage<unsigned char> &Ic, unsigned int gaussianFilterSize,
+                    double thresholdCanny, unsigned int apertureSobel);
 #endif
 
   /*!
@@ -78,7 +79,7 @@ public:
    \param r : coordinates (row) of the pixel
    \param c : coordinates (column) of the pixel
    */
-  template <class T> static double derivativeFilterX(const vpImage<T> &I, const unsigned int r, const unsigned int c)
+  template <class T> static double derivativeFilterX(const vpImage<T> &I, unsigned int r, unsigned int c)
   {
     return (2047.0 * (I[r][c + 1] - I[r][c - 1]) + 913.0 * (I[r][c + 2] - I[r][c - 2]) +
             112.0 * (I[r][c + 3] - I[r][c - 3])) /
@@ -92,7 +93,7 @@ public:
    \param r : coordinates (row) of the pixel
    \param c : coordinates (column) of the pixel
    */
-  template <class T> static double derivativeFilterY(const vpImage<T> &I, const unsigned int r, const unsigned int c)
+  template <class T> static double derivativeFilterY(const vpImage<T> &I, unsigned int r, unsigned int c)
   {
     return (2047.0 * (I[r + 1][c] - I[r - 1][c]) + 913.0 * (I[r + 2][c] - I[r - 2][c]) +
             112.0 * (I[r + 3][c] - I[r - 3][c])) /
@@ -113,8 +114,8 @@ public:
    */
 
   template <class T>
-  static double derivativeFilterX(const vpImage<T> &I, const unsigned int r, const unsigned int c, const double *filter,
-                                  const unsigned int size)
+  static double derivativeFilterX(const vpImage<T> &I, unsigned int r, unsigned int c, const double *filter,
+                                  unsigned int size)
   {
     unsigned int i;
     double result;
@@ -140,8 +141,8 @@ public:
   \sa vpImageFilter::getGaussianDerivativeKernel()
    */
   template <class T>
-  static double derivativeFilterY(const vpImage<T> &I, const unsigned int r, const unsigned int c, const double *filter,
-                                  const unsigned int size)
+  static double derivativeFilterY(const vpImage<T> &I, unsigned int r, unsigned int c, const double *filter,
+                                  unsigned int size)
   {
     unsigned int i;
     double result;
@@ -155,10 +156,10 @@ public:
   }
 
   static void filter(const vpImage<double> &I, vpImage<double> &Iu, vpImage<double> &Iv, const vpMatrix &M,
-                     const bool convolve = false);
+                     bool convolve = false);
 
   static void filter(const vpImage<unsigned char> &I, vpImage<double> &If, const vpMatrix &M,
-                     const bool convolve = false);
+                     bool convolve = false);
 
   static void sepFilter(const vpImage<unsigned char> &I, vpImage<double> &If, const vpColVector &kernelH,
                         const vpColVector &kernelV);
@@ -179,6 +180,10 @@ public:
 
   static void filterX(const vpImage<unsigned char> &I, vpImage<double> &dIx, const double *filter, unsigned int size);
   static void filterX(const vpImage<double> &I, vpImage<double> &dIx, const double *filter, unsigned int size);
+  static void filterX(const vpImage<vpRGBa> &I, vpImage<vpRGBa> &dIx, const double *filter, unsigned int size);
+  static void filterXR(const vpImage<vpRGBa> &I, vpImage<vpRGBa> &dIx, const double *filter, unsigned int size);
+  static void filterXG(const vpImage<vpRGBa> &I, vpImage<vpRGBa> &dIx, const double *filter, unsigned int size);
+  static void filterXB(const vpImage<vpRGBa> &I, vpImage<vpRGBa> &dIx, const double *filter, unsigned int size);
 
   static inline double filterX(const vpImage<unsigned char> &I, unsigned int r, unsigned int c, const double *filter,
                                unsigned int size)
@@ -193,6 +198,45 @@ public:
     return result + filter[0] * I[r][c];
   }
 
+  static inline double filterXR(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c, const double *filter,
+                               unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      result += filter[i] * (I[r][c + i].R + I[r][c - i].R);
+    }
+    return result + filter[0] * I[r][c].R;
+  }
+
+  static inline double filterXG(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c, const double *filter,
+                               unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      result += filter[i] * (I[r][c + i].G + I[r][c - i].G);
+    }
+    return result + filter[0] * I[r][c].G;
+  }
+
+  static inline double filterXB(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c, const double *filter,
+                               unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      result += filter[i] * (I[r][c + i].B + I[r][c - i].B);
+    }
+    return result + filter[0] * I[r][c].B;
+  }
+
   static inline double filterXLeftBorder(const vpImage<unsigned char> &I, unsigned int r, unsigned int c,
                                          const double *filter, unsigned int size)
   {
@@ -209,6 +253,54 @@ public:
     return result + filter[0] * I[r][c];
   }
 
+  static inline double filterXLeftBorderR(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                         const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (c > i)
+        result += filter[i] * (I[r][c + i].R + I[r][c - i].R);
+      else
+        result += filter[i] * (I[r][c + i].R + I[r][i - c].R);
+    }
+    return result + filter[0] * I[r][c].R;
+  }
+
+  static inline double filterXLeftBorderG(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                         const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (c > i)
+        result += filter[i] * (I[r][c + i].G + I[r][c - i].G);
+      else
+        result += filter[i] * (I[r][c + i].G + I[r][i - c].G);
+    }
+    return result + filter[0] * I[r][c].G;
+  }
+
+  static inline double filterXLeftBorderB(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                         const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (c > i)
+        result += filter[i] * (I[r][c + i].B + I[r][c - i].B);
+      else
+        result += filter[i] * (I[r][c + i].B + I[r][i - c].B);
+    }
+    return result + filter[0] * I[r][c].B;
+  }
+
   static inline double filterXRightBorder(const vpImage<unsigned char> &I, unsigned int r, unsigned int c,
                                           const double *filter, unsigned int size)
   {
@@ -225,6 +317,54 @@ public:
     return result + filter[0] * I[r][c];
   }
 
+  static inline double filterXRightBorderR(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                          const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (c + i < I.getWidth())
+        result += filter[i] * (I[r][c + i].R + I[r][c - i].R);
+      else
+        result += filter[i] * (I[r][2 * I.getWidth() - c - i - 1].R + I[r][c - i].R);
+    }
+    return result + filter[0] * I[r][c].R;
+  }
+
+  static inline double filterXRightBorderG(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                          const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (c + i < I.getWidth())
+        result += filter[i] * (I[r][c + i].G + I[r][c - i].G);
+      else
+        result += filter[i] * (I[r][2 * I.getWidth() - c - i - 1].G + I[r][c - i].G);
+    }
+    return result + filter[0] * I[r][c].G;
+  }
+
+  static inline double filterXRightBorderB(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                          const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (c + i < I.getWidth())
+        result += filter[i] * (I[r][c + i].B + I[r][c - i].B);
+      else
+        result += filter[i] * (I[r][2 * I.getWidth() - c - i - 1].B + I[r][c - i].B);
+    }
+    return result + filter[0] * I[r][c].B;
+  }
+
   static inline double filterX(const vpImage<double> &I, unsigned int r, unsigned int c, const double *filter,
                                unsigned int size)
   {
@@ -271,6 +411,10 @@ public:
   }
 
   static void filterY(const vpImage<unsigned char> &I, vpImage<double> &dIx, const double *filter, unsigned int size);
+  static void filterY(const vpImage<vpRGBa> &I, vpImage<vpRGBa> &dIx, const double *filter, unsigned int size);
+  static void filterYR(const vpImage<vpRGBa> &I, vpImage<vpRGBa> &dIx, const double *filter, unsigned int size);
+  static void filterYG(const vpImage<vpRGBa> &I, vpImage<vpRGBa> &dIx, const double *filter, unsigned int size);
+  static void filterYB(const vpImage<vpRGBa> &I, vpImage<vpRGBa> &dIx, const double *filter, unsigned int size);
   static void filterY(const vpImage<double> &I, vpImage<double> &dIx, const double *filter, unsigned int size);
   static inline double filterY(const vpImage<unsigned char> &I, unsigned int r, unsigned int c, const double *filter,
                                unsigned int size)
@@ -285,6 +429,43 @@ public:
     return result + filter[0] * I[r][c];
   }
 
+  static inline double filterYR(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c, const double *filter,
+                               unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      result += filter[i] * (I[r + i][c].R + I[r - i][c].R);
+    }
+    return result + filter[0] * I[r][c].R;
+  }
+  static inline double filterYG(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c, const double *filter,
+                               unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      result += filter[i] * (I[r + i][c].G + I[r - i][c].G);
+    }
+    return result + filter[0] * I[r][c].G;
+  }
+  static inline double filterYB(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c, const double *filter,
+                               unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      result += filter[i] * (I[r + i][c].B + I[r - i][c].B);
+    }
+    return result + filter[0] * I[r][c].B;
+  }
+
   double static inline filterYTopBorder(const vpImage<unsigned char> &I, unsigned int r, unsigned int c,
                                         const double *filter, unsigned int size)
   {
@@ -301,6 +482,54 @@ public:
     return result + filter[0] * I[r][c];
   }
 
+  double static inline filterYTopBorderR(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                        const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (r > i)
+        result += filter[i] * (I[r + i][c].R + I[r - i][c].R);
+      else
+        result += filter[i] * (I[r + i][c].R + I[i - r][c].R);
+    }
+    return result + filter[0] * I[r][c].R;
+  }
+
+  double static inline filterYTopBorderG(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                        const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (r > i)
+        result += filter[i] * (I[r + i][c].G + I[r - i][c].G);
+      else
+        result += filter[i] * (I[r + i][c].G + I[i - r][c].G);
+    }
+    return result + filter[0] * I[r][c].G;
+  }
+
+  double static inline filterYTopBorderB(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                        const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (r > i)
+        result += filter[i] * (I[r + i][c].B + I[r - i][c].B);
+      else
+        result += filter[i] * (I[r + i][c].B + I[i - r][c].B);
+    }
+    return result + filter[0] * I[r][c].B;
+  }
+
   double static inline filterYBottomBorder(const vpImage<unsigned char> &I, unsigned int r, unsigned int c,
                                            const double *filter, unsigned int size)
   {
@@ -317,6 +546,54 @@ public:
     return result + filter[0] * I[r][c];
   }
 
+  double static inline filterYBottomBorderR(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                           const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (r + i < I.getHeight())
+        result += filter[i] * (I[r + i][c].R + I[r - i][c].R);
+      else
+        result += filter[i] * (I[2 * I.getHeight() - r - i - 1][c].R + I[r - i][c].R);
+    }
+    return result + filter[0] * I[r][c].R;
+  }
+
+  double static inline filterYBottomBorderG(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                           const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (r + i < I.getHeight())
+        result += filter[i] * (I[r + i][c].G + I[r - i][c].G);
+      else
+        result += filter[i] * (I[2 * I.getHeight() - r - i - 1][c].G + I[r - i][c].G);
+    }
+    return result + filter[0] * I[r][c].G;
+  }
+
+  double static inline filterYBottomBorderB(const vpImage<vpRGBa> &I, unsigned int r, unsigned int c,
+                                           const double *filter, unsigned int size)
+  {
+    double result;
+
+    result = 0;
+
+    for (unsigned int i = 1; i <= (size - 1) / 2; i++) {
+      if (r + i < I.getHeight())
+        result += filter[i] * (I[r + i][c].B + I[r - i][c].B);
+      else
+        result += filter[i] * (I[2 * I.getHeight() - r - i - 1][c].B + I[r - i][c].B);
+    }
+    return result + filter[0] * I[r][c].B;
+  }
+
   static inline double filterYTopBorder(const vpImage<double> &I, unsigned int r, unsigned int c, const double *filter,
                                         unsigned int size)
   {
@@ -364,6 +641,8 @@ public:
 
   static void gaussianBlur(const vpImage<unsigned char> &I, vpImage<double> &GI, unsigned int size = 7,
                            double sigma = 0., bool normalize = true);
+  static void gaussianBlur(const vpImage<vpRGBa> &I, vpImage<vpRGBa> &GI, unsigned int size = 7,
+                           double sigma = 0., bool normalize = true);
   static void gaussianBlur(const vpImage<double> &I, vpImage<double> &GI, unsigned int size = 7, double sigma = 0.,
                            bool normalize = true);
   /*!
@@ -373,7 +652,7 @@ public:
    \param r : coordinates (row) of the pixel
    \param c : coordinates (column) of the pixel
    */
-  template <class T> static double gaussianFilter(const vpImage<T> &fr, const unsigned int r, const unsigned int c)
+  template <class T> static double gaussianFilter(const vpImage<T> &fr, unsigned int r, unsigned int c)
   {
     // filter Gaussien
     return (15.0 * fr[r][c] + 12.0 * (fr[r - 1][c] + fr[r][c - 1] + fr[r + 1][c] + fr[r][c + 1]) +
@@ -406,6 +685,9 @@ public:
   static void getGradY(const vpImage<double> &I, vpImage<double> &dIy, const double *filter, unsigned int size);
   static void getGradYGauss2D(const vpImage<unsigned char> &I, vpImage<double> &dIy, const double *gaussianKernel,
                               const double *gaussianDerivativeKernel, unsigned int size);
+
+  static double getSobelKernelX(double *filter, unsigned int size);
+  static double getSobelKernelY(double *filter, unsigned int size);
 };
 
 #endif
