@@ -74,10 +74,13 @@ class VISP_EXPORT vpMeterPixelConversion
 public:
   /** @name Using ViSP camera parameters  */
   //@{
-  static void convertEllipse(const vpCameraParameters &cam, const vpSphere &sphere, vpImagePoint &center,
-                             double &mu20_p, double &mu11_p, double &mu02_p);
-  static void convertEllipse(const vpCameraParameters &cam, const vpCircle &circle, vpImagePoint &center,
-                             double &mu20_p, double &mu11_p, double &mu02_p);
+  static void convertEllipse(const vpCameraParameters &cam, const vpSphere &sphere, vpImagePoint &center_p,
+                             double &n20_p, double &n11_p, double &n02_p);
+  static void convertEllipse(const vpCameraParameters &cam, const vpCircle &circle, vpImagePoint &center_p,
+                             double &n20_p, double &n11_p, double &n02_p);
+  static void convertEllipse(const vpCameraParameters &cam,
+                             double xc_m, double yc_m, double n20_m, double n11_m, double n02_m,
+                             vpImagePoint &center_p, double &n20_p, double &n11_p, double &n02_p);
   static void convertLine(const vpCameraParameters &cam, const double &rho_m, const double &theta_m, double &rho_p,
                           double &theta_p);
 
@@ -102,8 +105,10 @@ public:
     \f$ u = x*p_x*(1+k_{ud}*r^2)+u_0 \f$ and  \f$ v = y*p_y*(1+k_{ud}*r^2)+v_0
     \f$ with \f$ r^2 = x^2+y^2 \f$ in the  case of perspective projection with
     distortion.
-  */
 
+    In the case of a projection with Kannala-Brandt distortion, refer to
+    \cite KannalaBrandt.
+  */
   inline static void convertPoint(const vpCameraParameters &cam,
                                   const double &x, const double &y, double &u, double &v)
   {
@@ -114,6 +119,9 @@ public:
     case vpCameraParameters::perspectiveProjWithDistortion:
       convertPointWithDistortion(cam, x, y, u, v);
       break;
+    case vpCameraParameters::ProjWithKannalaBrandtDistortion:
+      convertPointWithKannalaBrandtDistortion(cam, x, y, u, v);
+      break;
     }
   }
 
@@ -139,6 +147,9 @@ public:
     \f$ u = x*p_x*(1+k_{ud}*r^2)+u_0 \f$ and  \f$ v = y*p_y*(1+k_{ud}*r^2)+v_0
     \f$ with \f$ r^2 = x^2+y^2 \f$ in the  case of perspective projection with
     distortion.
+
+    In the case of a projection with Kannala-Brandt distortion, refer to
+    \cite KannalaBrandt.
   */
 
   inline static void convertPoint(const vpCameraParameters &cam, const double &x, const double &y, vpImagePoint &iP)
@@ -150,6 +161,9 @@ public:
     case vpCameraParameters::perspectiveProjWithDistortion:
       convertPointWithDistortion(cam, x, y, iP);
       break;
+    case vpCameraParameters::ProjWithKannalaBrandtDistortion:
+      convertPointWithKannalaBrandtDistortion(cam, x, y, iP);
+      break;
     }
   }
 
@@ -195,7 +209,7 @@ public:
 
     \param[in] cam : camera parameters.
     \param[in] x : input coordinate in meter along image plane x-axis.
-    \param[in]y : input coordinate in meter along image plane y-axis.
+    \param[in] y : input coordinate in meter along image plane y-axis.
     \param[out] u : output coordinate in pixels along image horizontal axis.
     \param[out] v : output coordinate in pixels along image vertical axis.
 
@@ -234,6 +248,94 @@ public:
     iP.set_u(cam.u0 + cam.px * x * r2);
     iP.set_v(cam.v0 + cam.py * y * r2);
   }
+
+  /*!
+    Point coordinates conversion with Kannala-Brandt distortion from
+    normalized coordinates \f$(x,y)\f$ in meter to pixel coordinates
+    \f$(u,v)\f$.
+
+    \param[in] cam : camera parameters.
+    \param[in] x   : input coordinate in meter along image plane x-axis.
+    \param[in] y   : input coordinate in meter along image plane y-axis.
+    \param[out] u  : output coordinate in pixels along image horizontal axis.
+    \param[out] v  : output coordinate in pixels along image vertical axis.
+
+    \f$ r = sqrt{x^2 + y^2} \f$
+    \f$ \theta = \arctan{r} \f$
+    Calculate \f$ r_d \f$ knowing ditorsion coefficients as follows:
+    \f$ r_d = \theta + k_1 \theta^3 + k_2 \theta^5 + k_3 \theta^7 + k_4 \theta^9 \f$
+    \f$ scale = r_d / r \f$
+    \f$ x_d = x * scale \f$
+    \f$ y_d = y * scale \f$
+    \f$ u = x_d*p_x+u_0 \f$ and
+    \f$ v = y_d*p_y+v_0 \f$
+    with \f$ r^2 = x^2+y^2 \f$
+  */
+  inline static void convertPointWithKannalaBrandtDistortion(const vpCameraParameters &cam, const double &x, const double &y,
+                                                             double &u, double &v)
+  {
+    double r = sqrt(vpMath::sqr(x) + vpMath::sqr(y));
+    double theta = atan(r);
+
+    std::vector<double> k = cam.getKannalaBrandtDistortionCoefficients();
+
+    double theta2 = theta*theta, theta3 = theta2*theta, theta4 = theta2*theta2, theta5 = theta4*theta,
+          theta6 = theta3*theta3, theta7 = theta6*theta, theta8 = theta4*theta4, theta9 = theta8*theta;
+
+    double r_d = theta + k[0]*theta3 + k[1]*theta5 + k[2]*theta7 + k[3]*theta9;
+
+    double scale = (std::fabs(r) < std::numeric_limits<double>::epsilon()) ? 1.0 : r_d / r;
+
+    double x_d = x * scale;
+    double y_d = y * scale;
+
+    u = cam.px * x_d + cam.u0;
+    v = cam.py * y_d + cam.v0;
+  }
+
+  /*!
+    Point coordinates conversion with Kannala-Brandt distortion from
+    normalized coordinates \f$(x,y)\f$ in meter to pixel coordinates
+    \f$(u,v)\f$.
+
+    \param[in] cam : camera parameters.
+    \param[in] x : input coordinate in meter along image plane x-axis.
+    \param[in] y : input coordinate in meter along image plane y-axis.
+    \param[out] iP : output coordinates in pixels.
+
+    \f$ r = sqrt{x^2 + y^2} \f$
+    \f$ \theta = \arctan{r} \f$
+    Calculate \f$ r_d \f$ knowing ditorsion coefficients as follows:
+    \f$ r_d = \theta + k_1 \theta^3 + k_2 \theta^5 + k_3 \theta^7 + k_4 \theta^9 \f$
+    \f$ scale = r_d / r \f$
+    \f$ x_d = x * scale \f$
+    \f$ y_d = y * scale \f$
+    \f$ u = x_d*p_x+u_0 \f$ and
+    \f$ v = y_d*p_y+v_0 \f$
+    with \f$ r^2 = x^2+y^2 \f$
+  */
+  inline static void convertPointWithKannalaBrandtDistortion(const vpCameraParameters &cam, const double &x, const double &y,
+                                                             vpImagePoint &iP)
+  {
+    double r = sqrt(vpMath::sqr(x) + vpMath::sqr(y));
+    double theta = atan(r);
+
+    std::vector<double> k = cam.getKannalaBrandtDistortionCoefficients();
+
+    double theta2 = theta*theta, theta3 = theta2*theta, theta4 = theta2*theta2, theta5 = theta4*theta,
+          theta6 = theta3*theta3, theta7 = theta6*theta, theta8 = theta4*theta4, theta9 = theta8*theta;
+
+    double r_d = theta + k[0]*theta3 + k[1]*theta5 + k[2]*theta7 + k[3]*theta9;
+
+    double scale = (std::fabs(r) < std::numeric_limits<double>::epsilon()) ? 1.0 : r_d / r;
+
+    double x_d = x * scale;
+    double y_d = y * scale;
+
+    iP.set_u(cam.px * x_d + cam.u0);
+    iP.set_v(cam.py * y_d + cam.v0);
+  }
+
 #endif // #ifndef DOXYGEN_SHOULD_SKIP_THIS
   //@}
 
@@ -242,10 +344,13 @@ public:
   //@{
   static void convertEllipse(const cv::Mat &cameraMatrix,
                              const vpCircle &circle, vpImagePoint &center,
-                             double &mu20_p, double &mu11_p, double &mu02_p);
+                             double &n20_p, double &n11_p, double &n02_p);
   static void convertEllipse(const cv::Mat &cameraMatrix,
                              const vpSphere &sphere, vpImagePoint &center,
-                             double &mu20_p, double &mu11_p, double &mu02_p);
+                             double &n20_p, double &n11_p, double &n02_p);
+  static void convertEllipse(const cv::Mat &cameraMatrix,
+                             double xc_m, double yc_m, double n20_m, double n11_m, double n02_m,
+                             vpImagePoint &center_p, double &n20_p, double &n11_p, double &n02_p);
   static void convertLine(const cv::Mat &cameraMatrix,
                           const double &rho_m, const double &theta_m,
                           double &rho_p, double &theta_p);
