@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -87,9 +87,9 @@ public:
 
   void setImg(const vpImage<vpRGBa> &I);
   void setImg(const vpImage<unsigned char> &I);
-  void setImgROI(const vpImage<vpRGBa> &I, const vpImagePoint &iP, const unsigned int width, const unsigned int height);
-  void setImgROI(const vpImage<unsigned char> &I, const vpImagePoint &iP, const unsigned int width,
-                 const unsigned int height);
+  void setImgROI(const vpImage<vpRGBa> &I, const vpImagePoint &iP, unsigned int width, unsigned int height);
+  void setImgROI(const vpImage<unsigned char> &I, const vpImagePoint &iP, unsigned int width,
+                 unsigned int height);
 
   void setPixel(const vpImagePoint &iP, const vpColor &color);
 
@@ -126,12 +126,12 @@ private:
   void convert(const vpImage<unsigned char> &I, HBITMAP &hBmp);
 
   // converts a vpImage<vpRGBa> into a HBITMAP .
-  void convertROI(const vpImage<vpRGBa> &I, const vpImagePoint &iP, const unsigned int width,
-                  const unsigned int height);
+  void convertROI(const vpImage<vpRGBa> &I, const vpImagePoint &iP, unsigned int width,
+                  unsigned int height);
 
   // converst a vpImage<unsigned char> into a HBITMAP .
-  void convertROI(const vpImage<unsigned char> &I, const vpImagePoint &iP, const unsigned int width,
-                  const unsigned int height);
+  void convertROI(const vpImage<unsigned char> &I, const vpImagePoint &iP, unsigned int width,
+                  unsigned int height);
 };
 #endif
 #endif
