@@ -693,7 +693,7 @@ void vpRobotAfma6::powerOn(void)
       std::cout << "You have to call Adept for maintenance..." << std::endl;
       // Free allocated resources
       ShutDownConnection();
-      exit(0);
+      throw(vpRobotException(vpRobotException::lowLevelError, "Error on the emergency chain"));
     }
   }
 
@@ -702,7 +702,7 @@ void vpRobotAfma6::powerOn(void)
 
   if (EStopStatus == ESTOP_ACTIVATED) {
     std::cout << "Sorry, cannot power on the robot." << std::endl;
-    throw vpRobotException(vpRobotException::lowLevelError, "Cannot power on the robot.");
+    throw(vpRobotException(vpRobotException::lowLevelError, "Cannot power on the robot."));
   }
 
   if (HIPowerStatus == 0) {
@@ -715,7 +715,7 @@ void vpRobotAfma6::powerOn(void)
   CatchPrint();
   if (TryStt < 0) {
     vpERROR_TRACE("Cannot power on the robot");
-    throw vpRobotException(vpRobotException::lowLevelError, "Cannot power off the robot.");
+    throw(vpRobotException(vpRobotException::lowLevelError, "Cannot power off the robot."));
   }
 }
 
