@@ -58,7 +58,7 @@
 /* --- STATIC ----------------------------------------------------------- */
 /* ---------------------------------------------------------------------- */
 
-bool vpRobotViper850::robotAlreadyCreated = false;
+bool vpRobotViper850::m_robotAlreadyCreated = false;
 
 /*!
 
@@ -67,7 +67,7 @@ bool vpRobotViper850::robotAlreadyCreated = false;
   setPositioningVelocity() allows to change this value.
 
 */
-const double vpRobotViper850::defaultPositioningVelocity = 15.0;
+const double vpRobotViper850::m_defaultPositioningVelocity = 15.0;
 
 /* ---------------------------------------------------------------------- */
 /* --- EMERGENCY STOP --------------------------------------------------- */
@@ -211,11 +211,11 @@ vpRobotViper850::vpRobotViper850(bool verbose) : vpViper850(), vpRobot()
     //  vpERROR_TRACE("Error caught") ;
     throw;
   }
-  positioningVelocity = defaultPositioningVelocity;
+  m_positioningVelocity = m_defaultPositioningVelocity;
 
   maxRotationVelocity_joint6 = maxRotationVelocity;
 
-  vpRobotViper850::robotAlreadyCreated = true;
+  vpRobotViper850::m_robotAlreadyCreated = true;
 
   return;
 }
@@ -253,15 +253,15 @@ void vpRobotViper850::init(void)
   InitTry;
 
   // Initialise private variables used to compute the measured velocities
-  q_prev_getvel.resize(6);
-  q_prev_getvel = 0;
-  time_prev_getvel = 0;
-  first_time_getvel = true;
+  m_q_prev_getvel.resize(6);
+  m_q_prev_getvel = 0;
+  m_time_prev_getvel = 0;
+  m_first_time_getvel = true;
 
   // Initialise private variables used to compute the measured displacement
-  q_prev_getdis.resize(6);
-  q_prev_getdis = 0;
-  first_time_getdis = true;
+  m_q_prev_getdis.resize(6);
+  m_q_prev_getdis = 0;
+  m_first_time_getdis = true;
 
 #if defined(USE_ATI_DAQ) && defined(VISP_HAVE_COMEDI)
   std::string calibfile;
@@ -274,8 +274,8 @@ void vpRobotViper850::init(void)
                                           "data to retrive ATI F/T calib "
                                           "file"));
 #endif
-  ati.setCalibrationFile(calibfile);
-  ati.open();
+  m_ati.setCalibrationFile(calibfile);
+  m_ati.open();
 #endif
 
   // Initialize the firewire connection
@@ -303,7 +303,7 @@ void vpRobotViper850::init(void)
     std::cout << "Robot status: ";
     switch (EStopStatus) {
     case ESTOP_AUTO:
-      controlMode = AUTO;
+      m_controlMode = AUTO;
       if (HIPowerStatus == 0)
         std::cout << "Power is OFF" << std::endl;
       else
@@ -311,14 +311,14 @@ void vpRobotViper850::init(void)
       break;
 
     case ESTOP_MANUAL:
-      controlMode = MANUAL;
+      m_controlMode = MANUAL;
       if (HIPowerStatus == 0)
         std::cout << "Power is OFF" << std::endl;
       else
         std::cout << "Power is ON" << std::endl;
       break;
     case ESTOP_ACTIVATED:
-      controlMode = ESTOP;
+      m_controlMode = ESTOP;
       std::cout << "Emergency stop is activated" << std::endl;
       break;
     default:
@@ -674,7 +674,7 @@ void vpRobotViper850::set_eMc(const vpTranslationVector &etc_, const vpRxyzVecto
 vpRobotViper850::~vpRobotViper850(void)
 {
 #if defined(USE_ATI_DAQ) && defined(VISP_HAVE_COMEDI)
-  ati.close();
+  m_ati.close();
 #endif
 
   InitTry;
@@ -696,7 +696,7 @@ vpRobotViper850::~vpRobotViper850(void)
   // Free allocated resources
   ShutDownConnection();
 
-  vpRobotViper850::robotAlreadyCreated = false;
+  vpRobotViper850::m_robotAlreadyCreated = false;
 
   CatchPrint();
   return;
@@ -797,13 +797,13 @@ void vpRobotViper850::powerOn(void)
   for (unsigned int i = 0; i < nitermax; i++) {
     Try(PrimitiveSTATUS_Viper850(NULL, NULL, &EStopStatus, NULL, NULL, NULL, &HIPowerStatus));
     if (EStopStatus == ESTOP_AUTO) {
-      controlMode = AUTO;
+      m_controlMode = AUTO;
       break; // exit for loop
     } else if (EStopStatus == ESTOP_MANUAL) {
-      controlMode = MANUAL;
+      m_controlMode = MANUAL;
       break; // exit for loop
     } else if (EStopStatus == ESTOP_ACTIVATED) {
-      controlMode = ESTOP;
+      m_controlMode = ESTOP;
       if (firsttime) {
         std::cout << "Emergency stop is activated! \n"
                   << "Check the emergency stop button and push the yellow "
@@ -819,7 +819,7 @@ void vpRobotViper850::powerOn(void)
       std::cout << "You have to call Adept for maintenance..." << std::endl;
       // Free allocated resources
       ShutDownConnection();
-      exit(0);
+      throw(vpRobotException(vpRobotException::lowLevelError, "Error on the emergency chain"));
     }
   }
 
@@ -828,7 +828,7 @@ void vpRobotViper850::powerOn(void)
 
   if (EStopStatus == ESTOP_ACTIVATED) {
     std::cout << "Sorry, cannot power on the robot." << std::endl;
-    throw vpRobotException(vpRobotException::lowLevelError, "Cannot power on the robot.");
+    throw(vpRobotException(vpRobotException::lowLevelError, "Cannot power on the robot."));
   }
 
   if (HIPowerStatus == 0) {
@@ -841,7 +841,7 @@ void vpRobotViper850::powerOn(void)
   CatchPrint();
   if (TryStt < 0) {
     vpERROR_TRACE("Cannot power on the robot");
-    throw vpRobotException(vpRobotException::lowLevelError, "Cannot power off the robot.");
+    throw(vpRobotException(vpRobotException::lowLevelError, "Cannot power off the robot."));
   }
 }
 
@@ -1010,7 +1010,7 @@ void vpRobotViper850::get_fJe(vpMatrix &fJe)
   Set the maximal velocity percentage to use for a position control.
 
   The default positioning velocity is defined by
-  vpRobotViper850::defaultPositioningVelocity. This method allows to
+  vpRobotViper850::m_defaultPositioningVelocity. This method allows to
   change this default positioning velocity
 
   \param velocity : Percentage of the maximal velocity. Values should
@@ -1041,14 +1041,14 @@ int main()
 
   \sa getPositioningVelocity()
 */
-void vpRobotViper850::setPositioningVelocity(double velocity) { positioningVelocity = velocity; }
+void vpRobotViper850::setPositioningVelocity(double velocity) { m_positioningVelocity = velocity; }
 
 /*!
   Get the maximal velocity percentage used for a position control.
 
   \sa setPositioningVelocity()
 */
-double vpRobotViper850::getPositioningVelocity(void) const { return positioningVelocity; }
+double vpRobotViper850::getPositioningVelocity(void) const { return m_positioningVelocity; }
 
 /*!
 
@@ -1174,7 +1174,7 @@ void vpRobotViper850::setPosition(const vpRobot::vpControlFrameType frame, const
       destination = q;
       // convert rad to deg requested for the low level controller
       destination.rad2deg();
-      Try(PrimitiveMOVE_J_Viper850(destination.data, positioningVelocity));
+      Try(PrimitiveMOVE_J_Viper850(destination.data, m_positioningVelocity));
       Try(WaitState_Viper850(ETAT_ATTENTE_VIPER850, 1000));
     } else {
       // Cartesian position is out of range
@@ -1190,7 +1190,7 @@ void vpRobotViper850::setPosition(const vpRobot::vpControlFrameType frame, const
 
     // std::cout << "Joint destination (deg): " << destination.t() <<
     // std::endl;
-    Try(PrimitiveMOVE_J_Viper850(destination.data, positioningVelocity));
+    Try(PrimitiveMOVE_J_Viper850(destination.data, m_positioningVelocity));
     Try(WaitState_Viper850(ETAT_ATTENTE_VIPER850, 1000));
     break;
   }
@@ -1208,7 +1208,7 @@ void vpRobotViper850::setPosition(const vpRobot::vpControlFrameType frame, const
 
     // std::cout << "Base frame destination Rzyz (deg): " << destination.t()
     // << std::endl;
-    Try(PrimitiveMOVE_C_Viper850(destination.data, configuration, positioningVelocity));
+    Try(PrimitiveMOVE_C_Viper850(destination.data, configuration, m_positioningVelocity));
     Try(WaitState_Viper850(ETAT_ATTENTE_VIPER850, 1000));
 
     break;
@@ -1846,13 +1846,12 @@ int main()
 */
 void vpRobotViper850::getVelocity(const vpRobot::vpControlFrameType frame, vpColVector &velocity, double &timestamp)
 {
-
   velocity.resize(6);
   velocity = 0;
 
   vpColVector q_cur(6);
-  vpHomogeneousMatrix fMc_cur;
-  vpHomogeneousMatrix cMc; // camera displacement
+  vpHomogeneousMatrix fMe_cur, fMc_cur;
+  vpHomogeneousMatrix eMe, cMc; // camera displacement
   double time_cur;
 
   InitTry;
@@ -1862,34 +1861,46 @@ void vpRobotViper850::getVelocity(const vpRobot::vpControlFrameType frame, vpCol
   time_cur = timestamp;
   q_cur.deg2rad();
 
+  // Get the end-effector pose from the direct kinematics
+  vpViper850::get_fMe(q_cur, fMe_cur);
   // Get the camera pose from the direct kinematics
   vpViper850::get_fMc(q_cur, fMc_cur);
 
-  if (!first_time_getvel) {
+  if (!m_first_time_getvel) {
 
     switch (frame) {
+    case vpRobot::END_EFFECTOR_FRAME: {
+      // Compute the displacement of the end-effector since the previous call
+      eMe = m_fMe_prev_getvel.inverse() * fMe_cur;
+
+      // Compute the velocity of the end-effector from this displacement
+      velocity = vpExponentialMap::inverse(eMe, time_cur - m_time_prev_getvel);
+
+      break;
+    }
+
     case vpRobot::CAMERA_FRAME: {
       // Compute the displacement of the camera since the previous call
-      cMc = fMc_prev_getvel.inverse() * fMc_cur;
+      cMc = m_fMc_prev_getvel.inverse() * fMc_cur;
 
       // Compute the velocity of the camera from this displacement
-      velocity = vpExponentialMap::inverse(cMc, time_cur - time_prev_getvel);
+      velocity = vpExponentialMap::inverse(cMc, time_cur - m_time_prev_getvel);
 
       break;
     }
 
     case vpRobot::ARTICULAR_FRAME: {
-      velocity = (q_cur - q_prev_getvel) / (time_cur - time_prev_getvel);
+      velocity = (q_cur - m_q_prev_getvel) / (time_cur - m_time_prev_getvel);
       break;
     }
 
     case vpRobot::REFERENCE_FRAME: {
       // Compute the displacement of the camera since the previous call
-      cMc = fMc_prev_getvel.inverse() * fMc_cur;
+      cMc = m_fMc_prev_getvel.inverse() * fMc_cur;
 
       // Compute the velocity of the camera from this displacement
       vpColVector v;
-      v = vpExponentialMap::inverse(cMc, time_cur - time_prev_getvel);
+      v = vpExponentialMap::inverse(cMc, time_cur - m_time_prev_getvel);
 
       // Express this velocity in the reference frame
       vpVelocityTwistMatrix fVc(fMc_cur);
@@ -1900,7 +1911,7 @@ void vpRobotViper850::getVelocity(const vpRobot::vpControlFrameType frame, vpCol
 
     case vpRobot::MIXT_FRAME: {
       // Compute the displacement of the camera since the previous call
-      cMc = fMc_prev_getvel.inverse() * fMc_cur;
+      cMc = m_fMc_prev_getvel.inverse() * fMc_cur;
 
       // Compute the ThetaU representation for the rotation
       vpRotationMatrix cRc;
@@ -1910,13 +1921,13 @@ void vpRobotViper850::getVelocity(const vpRobot::vpControlFrameType frame, vpCol
 
       for (unsigned int i = 0; i < 3; i++) {
         // Compute the translation displacement in the reference frame
-        velocity[i] = fMc_prev_getvel[i][3] - fMc_cur[i][3];
+        velocity[i] = m_fMc_prev_getvel[i][3] - fMc_cur[i][3];
         // Update the rotation displacement in the camera frame
         velocity[i + 3] = thetaU[i];
       }
 
       // Compute the velocity
-      velocity /= (time_cur - time_prev_getvel);
+      velocity /= (time_cur - m_time_prev_getvel);
       break;
     }
     default: {
@@ -1925,17 +1936,19 @@ void vpRobotViper850::getVelocity(const vpRobot::vpControlFrameType frame, vpCol
     }
     }
   } else {
-    first_time_getvel = false;
+    m_first_time_getvel = false;
   }
 
+  // Memorize the end-effector pose for the next call
+  m_fMe_prev_getvel = fMe_cur;
   // Memorize the camera pose for the next call
-  fMc_prev_getvel = fMc_cur;
+  m_fMc_prev_getvel = fMc_cur;
 
   // Memorize the joint position for the next call
-  q_prev_getvel = q_cur;
+  m_q_prev_getvel = q_cur;
 
   // Memorize the time associated to the joint position for the next call
-  time_prev_getvel = time_cur;
+  m_time_prev_getvel = time_cur;
 
   CatchPrint();
   if (TryStt < 0) {
@@ -2261,7 +2274,7 @@ void vpRobotViper850::getDisplacement(vpRobot::vpControlFrameType frame, vpColVe
     q_cur[i] = q[i];
   }
 
-  if (!first_time_getdis) {
+  if (!m_first_time_getdis) {
     switch (frame) {
     case vpRobot::CAMERA_FRAME: {
       std::cout << "getDisplacement() CAMERA_FRAME not implemented\n";
@@ -2269,7 +2282,7 @@ void vpRobotViper850::getDisplacement(vpRobot::vpControlFrameType frame, vpColVe
     }
 
     case vpRobot::ARTICULAR_FRAME: {
-      displacement = q_cur - q_prev_getdis;
+      displacement = q_cur - m_q_prev_getdis;
       break;
     }
 
@@ -2288,11 +2301,11 @@ void vpRobotViper850::getDisplacement(vpRobot::vpControlFrameType frame, vpColVe
     }
     }
   } else {
-    first_time_getdis = false;
+    m_first_time_getdis = false;
   }
 
   // Memorize the joint position for the next call
-  q_prev_getdis = q_cur;
+  m_q_prev_getdis = q_cur;
 
   CatchPrint();
   if (TryStt < 0) {
@@ -2312,7 +2325,7 @@ void vpRobotViper850::biasForceTorqueSensor()
 {
 #if defined(USE_ATI_DAQ)
 #if defined(VISP_HAVE_COMEDI)
-  ati.bias();
+  m_ati.bias();
 #else
   throw(vpException(vpException::fatalError, "Cannot use ATI F/T if comedi is not installed. Try sudo "
                                              "apt-get install libcomedi-dev"));
@@ -2344,7 +2357,7 @@ void vpRobotViper850::unbiasForceTorqueSensor()
 {
 #if defined(USE_ATI_DAQ)
 #if defined(VISP_HAVE_COMEDI)
-  ati.unbias();
+  m_ati.unbias();
 #else
   throw(vpException(vpException::fatalError, "Cannot use ATI F/T if comedi is not installed. Try sudo "
                                              "apt-get install libcomedi-dev"));
@@ -2397,7 +2410,7 @@ void vpRobotViper850::getForceTorque(vpColVector &H) const
 {
 #if defined(USE_ATI_DAQ)
 #if defined(VISP_HAVE_COMEDI)
-  H = ati.getForceTorque();
+  H = m_ati.getForceTorque();
 #else
   (void)H;
   throw(vpException(vpException::fatalError, "Cannot use ATI F/T if comedi is not installed. Try sudo "
@@ -2459,7 +2472,7 @@ vpColVector vpRobotViper850::getForceTorque() const
 {
 #if defined(USE_ATI_DAQ)
 #if defined(VISP_HAVE_COMEDI)
-  vpColVector H = ati.getForceTorque();
+  vpColVector H = m_ati.getForceTorque();
   return H;
 #else
   throw(vpException(vpException::fatalError, "Cannot use ATI F/T if comedi is not installed. Try sudo "
