@@ -388,9 +388,17 @@ void vpSimulatorAfma6::init(vpAfma6::vpAfma6ToolType tool, vpCameraParameters::v
     }
     break;
   }
-  case vpAfma6::TOOL_CUSTOM:
+  case vpAfma6::TOOL_CUSTOM:  {
+    std::cout << "The custom tool is not handled in vpSimulatorAfma6.cpp" << std::endl;
+    break;
+  }
+  case vpAfma6::TOOL_INTEL_D435_CAMERA: {
+    std::cout << "The Intel D435 camera is not handled in vpSimulatorAfma6.cpp" << std::endl;
+    break;
+  }
   case vpAfma6::TOOL_GENERIC_CAMERA: {
     std::cout << "The generic camera is not handled in vpSimulatorAfma6.cpp" << std::endl;
+    break;
   }
   }
 
@@ -443,12 +451,22 @@ void vpSimulatorAfma6::getCameraParameters(vpCameraParameters &cam, const unsign
     }
     break;
   }
-  case vpAfma6::TOOL_CUSTOM:
-  case vpAfma6::TOOL_GENERIC_CAMERA:
-  case vpAfma6::TOOL_VACUUM: {
+  case vpAfma6::TOOL_CUSTOM: {
+    std::cout << "The generic tool is not handled in vpSimulatorAfma6.cpp" << std::endl;
+    break;
+  }
+  case vpAfma6::TOOL_INTEL_D435_CAMERA: {
+    std::cout << "The Intel D435 camera is not handled in vpSimulatorAfma6.cpp" << std::endl;
+    break;
+  }
+  case vpAfma6::TOOL_GENERIC_CAMERA: {
     std::cout << "The generic camera is not handled in vpSimulatorAfma6.cpp" << std::endl;
     break;
   }
+  case vpAfma6::TOOL_VACUUM: {
+    std::cout << "The vacuum tool is not handled in vpSimulatorAfma6.cpp" << std::endl;
+    break;
+  }
   default:
     vpERROR_TRACE("This error should not occur!");
     break;
@@ -2248,6 +2266,10 @@ void vpSimulatorAfma6::initArms()
     std::cout << "The custom tool is not handled in vpSimulatorAfma6.cpp" << std::endl;
     break;
   }
+  case vpAfma6::TOOL_INTEL_D435_CAMERA: {
+    std::cout << "The Intel D435 camera is not handled in vpSimulatorAfma6.cpp" << std::endl;
+    break;
+  }
   case vpAfma6::TOOL_GENERIC_CAMERA: {
     std::cout << "The generic camera is not handled in vpSimulatorAfma6.cpp" << std::endl;
     break;
