@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -802,7 +802,6 @@ reference frame in m/s and rotations \f$ ^{c} \omega_x, ^{c} \omega_y, ^{c}
 
   \code
 #include <visp3/core/vpColVector.h>
-#include <visp3/core/vpConfig.h>
 #include <visp3/core/vpMath.h>
 #include <visp3/robot/vpSimulatorViper850.h>
 
@@ -918,6 +917,7 @@ void vpSimulatorViper850::setVelocity(const vpRobot::vpControlFrameType frame, c
       scale_sat = scale_rot_sat;
     break;
   }
+  case vpRobot::END_EFFECTOR_FRAME:
   case vpRobot::MIXT_FRAME: {
     break;
   }
@@ -968,6 +968,7 @@ void vpSimulatorViper850::computeArticularVelocity()
     set_artVel(articularVelocity);
     break;
   }
+  case vpRobot::END_EFFECTOR_FRAME:
   case vpRobot::MIXT_FRAME: {
     break;
   }
@@ -996,6 +997,7 @@ void vpSimulatorViper850::computeArticularVelocity()
     set_artVel(articularVelocity * scale_sat);
     break;
   }
+  case vpRobot::END_EFFECTOR_FRAME:
   case vpRobot::ARTICULAR_FRAME:
   case vpRobot::MIXT_FRAME: {
     break;
@@ -1017,7 +1019,6 @@ void vpSimulatorViper850::computeArticularVelocity()
 
   \code
 #include <visp3/core/vpColVector.h>
-#include <visp3/core/vpConfig.h>
 #include <visp3/robot/vpSimulatorViper850.h>
 
 int main()
@@ -1074,6 +1075,7 @@ void vpSimulatorViper850::getVelocity(const vpRobot::vpControlFrameType frame, v
     vel = fJe_ * articularVelocity;
     break;
   }
+  case vpRobot::END_EFFECTOR_FRAME:
   case vpRobot::MIXT_FRAME: {
     break;
   }
@@ -1117,7 +1119,6 @@ void vpSimulatorViper850::getVelocity(const vpRobot::vpControlFrameType frame, v
 
   \code
 #include <visp3/core/vpColVector.h>
-#include <visp3/core/vpConfig.h>
 #include <visp3/robot/vpSimulatorViper850.h>
 
 int main()
@@ -1226,7 +1227,6 @@ void vpSimulatorViper850::findHighestPositioningSpeed(vpColVector &q)
 
   \code
 #include <visp3/core/vpColVector.h>
-#include <visp3/core/vpConfig.h>
 #include <visp3/robot/vpSimulatorViper850.h>
 
 int main()
@@ -1380,10 +1380,13 @@ void vpSimulatorViper850::setPosition(const vpRobot::vpControlFrameType frame, c
     break;
   }
   case vpRobot::MIXT_FRAME: {
-    vpERROR_TRACE("Positionning error. Mixt frame not implemented");
     throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
                                                             "Mixt frame not implemented.");
   }
+  case vpRobot::END_EFFECTOR_FRAME: {
+    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
+                                                            "End-effector frame not implemented.");
+  }
   }
 }
 
@@ -1423,7 +1426,6 @@ void vpSimulatorViper850::setPosition(const vpRobot::vpControlFrameType frame, c
   position is out of range.
 
   \code
-#include <visp3/core/vpConfig.h>
 #include <visp3/robot/vpSimulatorViper850.h>
 
 int main()
@@ -1450,8 +1452,8 @@ int main()
 
   \sa setPosition()
 */
-void vpSimulatorViper850::setPosition(const vpRobot::vpControlFrameType frame, const double pos1, const double pos2,
-                                      const double pos3, const double pos4, const double pos5, const double pos6)
+void vpSimulatorViper850::setPosition(const vpRobot::vpControlFrameType frame, double pos1, double pos2,
+                                      double pos3, double pos4, double pos5,  double pos6)
 {
   try {
     vpColVector position(6);
@@ -1482,7 +1484,6 @@ void vpSimulatorViper850::setPosition(const vpRobot::vpControlFrameType frame, c
   This method has the same behavior than the sample code given below;
   \code
 #include <visp3/core/vpColVector.h>
-#include <visp3/core/vpConfig.h>
 #include <visp3/robot/vpSimulatorViper850.h>
 
 int main()
@@ -1542,7 +1543,6 @@ void vpSimulatorViper850::setPosition(const char *filename)
 
   \code
 #include <visp3/core/vpColVector.h>
-#include <visp3/core/vpConfig.h>
 #include <visp3/core/vpHomogeneousMatrix.h>
 #include <visp3/core/vpRotationMatrix.h>
 #include <visp3/core/vpRxyzVector.h>
@@ -1617,6 +1617,11 @@ void vpSimulatorViper850::getPosition(const vpRobot::vpControlFrameType frame, v
     throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
                                                             "Mixt frame not implemented.");
   }
+  case vpRobot::END_EFFECTOR_FRAME: {
+    vpERROR_TRACE("Positionning error. Mixt frame not implemented");
+    throw vpRobotException(vpRobotException::lowLevelError, "Positionning error: "
+                                                            "End-effector frame not implemented.");
+  }
   }
 }
 
@@ -1882,6 +1887,10 @@ void vpSimulatorViper850::getDisplacement(vpRobot::vpControlFrameType frame, vpC
       std::cout << "getDisplacement() MIXT_FRAME not implemented\n";
       return;
     }
+    case vpRobot::END_EFFECTOR_FRAME: {
+      std::cout << "getDisplacement() END_EFFECTOR_FRAME not implemented\n";
+      return;
+    }
     }
   } else {
     first_time_getdis = false;
@@ -1926,7 +1935,6 @@ The code below shows how to read a position from a file and move the robot to
 this position.
 \code
 #include <visp3/core/vpColVector.h>
-#include <visp3/core/vpConfig.h>
 #include <visp3/robot/vpSimulatorViper850.h>
 
 int main()
