@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -868,7 +868,7 @@ std::pair<unsigned int, unsigned int> vpFlyCaptureGrabber::centerRoi(unsigned in
   Set format7 video mode.
   \param format7_mode : Format 7 mode.
   \param pixel_format : Pixel format.
-  \param width,height : Size of the centered roi. If set to 0, use the max
+  \param w,h : Width and height of the centered roi. If set to 0, use the max
 allowed size.
 
   If the format7 video mode and pixel format are not supported, return an
@@ -898,7 +898,7 @@ int main()
   \endcode
  */
 void vpFlyCaptureGrabber::setFormat7VideoMode(FlyCapture2::Mode format7_mode, FlyCapture2::PixelFormat pixel_format,
-                                              unsigned int width, unsigned int height)
+                                              unsigned int w, unsigned int h)
 {
   this->connect();
 
@@ -920,8 +920,8 @@ void vpFlyCaptureGrabber::setFormat7VideoMode(FlyCapture2::Mode format7_mode, Fl
   fmt7_settings.mode = format7_mode;
   fmt7_settings.pixelFormat = pixel_format;
   // Set centered roi
-  std::pair<unsigned int, unsigned int> roi_w = this->centerRoi(width, fmt7_info.maxWidth, fmt7_info.imageHStepSize);
-  std::pair<unsigned int, unsigned int> roi_h = this->centerRoi(height, fmt7_info.maxHeight, fmt7_info.imageVStepSize);
+  std::pair<unsigned int, unsigned int> roi_w = this->centerRoi(w, fmt7_info.maxWidth, fmt7_info.imageHStepSize);
+  std::pair<unsigned int, unsigned int> roi_h = this->centerRoi(h, fmt7_info.maxHeight, fmt7_info.imageVStepSize);
   fmt7_settings.width = roi_w.first;
   fmt7_settings.offsetX = roi_w.second;
   fmt7_settings.height = roi_h.first;
@@ -1119,8 +1119,7 @@ void vpFlyCaptureGrabber::acquire(vpImage<unsigned char> &I, FlyCapture2::TimeSt
   error = m_camera.RetrieveBuffer(&m_rawImage);
   if (error != FlyCapture2::PGRERROR_OK) {
     error.PrintErrorTrace();
-    throw(vpException(vpException::fatalError, "Cannot retrieve image from camera with serial %u",
-                      getCameraSerial(m_index)));
+    std::cerr << "Cannot retrieve image from camera with serial " << getCameraSerial(m_index) << std::endl;
   }
   timestamp = m_rawImage.GetTimeStamp();
 
@@ -1171,8 +1170,7 @@ void vpFlyCaptureGrabber::acquire(vpImage<vpRGBa> &I, FlyCapture2::TimeStamp &ti
   error = m_camera.RetrieveBuffer(&m_rawImage);
   if (error != FlyCapture2::PGRERROR_OK) {
     error.PrintErrorTrace();
-    throw(vpException(vpException::fatalError, "Cannot retrieve image from camera with serial %u",
-                      getCameraSerial(m_index)));
+    std::cerr << "Cannot retrieve image from camera with serial " << getCameraSerial(m_index) << std::endl;
   }
   timestamp = m_rawImage.GetTimeStamp();
 
@@ -1335,7 +1333,7 @@ void vpFlyCaptureGrabber::setCameraPower(bool on)
     throw(vpException(vpException::fatalError, "Cannot power on the camera."));
   }
 
-  const unsigned int millisecondsToSleep = 100;
+  unsigned int millisecondsToSleep = 100;
   unsigned int regVal = 0;
   unsigned int retries = 10;
 
