@@ -125,72 +125,72 @@ public:
        right, up, down, and the 4 pixels located on the diagonal) */
   } vpConnexityType;
 
-  static const unsigned int SPIRAL_SEARCH_SIZE; /*!< Spiral size for the dot
-              search. */
-  double m00;                                   /*!< Considering the general distribution moments for \f$ N \f$
-                                      points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
-                                      u_h^i v_h^j \f$, \f$ m_{00} \f$ is a zero order moment obtained
-                                      with \f$i = j = 0 \f$.
+#ifdef VISP_BUILD_DEPRECATED_FUNCTIONS
+public:
+#else
+private:
+#endif
+  static const unsigned int SPIRAL_SEARCH_SIZE; /*!< Spiral size for the dot search. */
 
-                                      \sa setComputeMoments()
-                                          */
-  double m01;                                   /*!< Considering the general distribution moments for \f$ N \f$
-                                      points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
-                                      u_h^i v_h^j \f$, \f$ m_{01} \f$ is a first order moment
-                                      obtained with \f$i = 0 \f$ and \f$ j = 1 \f$.
+  double m00; /*!< Considering the general distribution moments for \f$ N \f$
+                   points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
+                   u_h^i v_h^j \f$, \f$ m_{00} \f$ is a zero order moment obtained
+                   with \f$i = j = 0 \f$.
 
-                                      \sa setComputeMoments()
-                                          */
-  double m10;                                   /*!< Considering the general distribution moments for \f$ N \f$
-                                      points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
-                                      u_h^i v_h^j \f$, \f$ m_{10} \f$ is a first order moment
-                                      obtained with \f$i = 1 \f$ and \f$ j = 0 \f$.
+                   \sa setComputeMoments()
+               */
+  double m01; /*!< Considering the general distribution moments for \f$ N \f$
+                   points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
+                   u_h^i v_h^j \f$, \f$ m_{01} \f$ is a first order moment
+                   obtained with \f$i = 0 \f$ and \f$ j = 1 \f$.
 
-                                      \sa setComputeMoments()
-                                          */
-  double m11;                                   /*!< Considering the general distribution moments for \f$ N \f$
-                                      points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
-                                      u_h^i v_h^j \f$, \f$ m_{11} \f$ is a first order moment
-                                      obtained with \f$i = 1 \f$ and \f$ j = 1 \f$.
+                   \sa setComputeMoments()
+               */
+  double m10; /*!< Considering the general distribution moments for \f$ N \f$
+                   points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
+                   u_h^i v_h^j \f$, \f$ m_{10} \f$ is a first order moment
+                   obtained with \f$i = 1 \f$ and \f$ j = 0 \f$.
 
-                                      \warning This moment is not computed for the moment.
+                   \sa setComputeMoments()
+               */
+  double m11; /*!< Considering the general distribution moments for \f$ N \f$
+                   points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
+                   u_h^i v_h^j \f$, \f$ m_{11} \f$ is a first order moment
+                   obtained with \f$i = 1 \f$ and \f$ j = 1 \f$.
 
-                                      \sa setComputeMoments()
-                                          */
-  double m20;                                   /*!< Considering the general distribution moments for \f$ N \f$
-                                      points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
-                                      u_h^i v_h^j \f$, \f$ m_{20} \f$ is a second order moment
-                                      obtained with \f$i = 2 \f$ and \f$ j = 0 \f$.
+                   \sa setComputeMoments()
+               */
+  double m20; /*!< Considering the general distribution moments for \f$ N \f$
+                   points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
+                   u_h^i v_h^j \f$, \f$ m_{20} \f$ is a second order moment
+                   obtained with \f$i = 2 \f$ and \f$ j = 0 \f$.
 
-                                      \warning This moment is not computed for the moment.
+                   \sa setComputeMoments()
+               */
+  double m02; /*!< Considering the general distribution moments for \f$ N \f$
+                   points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
+                   u_h^i v_h^j \f$, \f$ m_{02} \f$ is a second order moment
+                   obtained with \f$i = 0 \f$ and \f$ j = 2 \f$.
 
-                                      \sa setComputeMoments()
-                                          */
-  double m02;                                   /*!< Considering the general distribution moments for \f$ N \f$
-                                      points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
-                                      u_h^i v_h^j \f$, \f$ m_{02} \f$ is a second order moment
-                                      obtained with \f$i = 0 \f$ and \f$ j = 2 \f$.
+                    \sa setComputeMoments()
+               */
+  double mu11; /*!< \f$ \mu_{11} \f$ is a second order centered moment defined
+                    by: \f$ \mu_{11} = m_{11} - \frac{m_{10}}{m_{00}}m_{01} \f$
 
-                                      \warning This moment is not computed for the moment.
+                    \sa setComputeMoments()
+                */
+  double mu20; /*!< \f$ \mu_{20} \f$ is a second order centered moment defined
+                    by: \f$ \mu_{20} = m_{20} - \frac{m_{10}}{m_{00}}m_{10} \f$
 
-                                      \sa setComputeMoments()
-                                          */
-  double mu11;                                  /*!< \f$ \mu_{11} \f$ is a second order central moments defined
-                                      by: \f$ \mu_{11} = m_{11} - \frac{m_{10}}{m_{00}}m_{01} \f$
+                    \sa setComputeMoments()
+                */
+  double mu02; /*!< \f$ \mu_{02} \f$ is a second order centered moment defined
+                     by: \f$ \mu_{02} = m_{02} - \frac{m_{01}}{m_{00}}m_{01} \f$
 
-                                      \sa setComputeMoments()
-                                          */
-  double mu20;                                  /*!< \f$ \mu_{20} \f$ is a second order central moments defined
-                                      by: \f$ \mu_{20} = m_{20} - \frac{m_{10}}{m_{00}}m_{10} \f$
-
-                                      \sa setComputeMoments()
-                                          */
-  double mu02;                                  /*!< \f$ \mu_{02} \f$ is a second order central moments defined
-                                      by: \f$ \mu_{02} = m_{02} - \frac{m_{01}}{m_{00}}m_{01} \f$
-
-                                      \sa setComputeMoments()
-                                          */
+                     \sa setComputeMoments()
+                */
 
+public:
   vpDot();
   explicit vpDot(const vpImagePoint &ip);
   vpDot(const vpDot &d);
@@ -198,6 +198,32 @@ public:
 
   void display(const vpImage<unsigned char> &I, vpColor color = vpColor::red, unsigned int thickness = 1) const;
 
+  /*!
+    Gets the second order normalized centered moment \f$ n_{ij} \f$
+    as a 3-dim vector containing \f$ n_{20}, n_{11}, n_{02} \f$
+    such as \f$ n_{ij}  = \mu_{ij}/m_{00} \f$
+
+    \return The 3-dim vector containing \f$ n_{20}, n_{11}, n_{02} \f$.
+
+    \sa getCog(), getArea()
+  */
+  inline vpColVector get_nij() const
+  {
+    vpColVector nij(3);
+    nij[0] = mu20 / m00;
+    nij[1] = mu11 / m00;
+    nij[2] = mu02 / m00;
+
+    return nij;
+  }
+
+  /*!
+    Gets the area of the blob corresponding also to the zero order moment.
+
+    \return The blob area.
+  */
+  inline double getArea() const { return m00; }
+
   /*!
 
     Return the dot bounding box.
@@ -301,7 +327,8 @@ public:
     moments are not computed.
 
     Computed moment are vpDot::m00, vpDot::m10, vpDot::m01, vpDot::m11,
-    vpDot::m20, vpDot::m02.
+    vpDot::m20, vpDot::m02 and second order centered moments vpDot::mu11,
+    vpDot::mu20, vpDot::mu02 computed with respect to the blob centroid.
 
     The coordinates of the region's centroid (u, v) can be computed from the
     moments by \f$u=\frac{m10}{m00}\f$ and  \f$v=\frac{m01}{m00}\f$.
