@@ -136,6 +136,25 @@ public:
 
   void display(const vpImage<unsigned char> &I, vpColor color = vpColor::red, unsigned int thickness = 1) const;
 
+  /*!
+    Gets the second order normalized centered moment \f$ n_{ij} \f$
+    as a 3-dim vector containing \f$ n_{20}, n_{11}, n_{02} \f$
+    such as \f$ n_{ij}  = \mu_{ij}/m_{00} \f$
+
+    \return The 3-dim vector containing \f$ n_{20}, n_{11}, n_{02} \f$.
+
+    \sa getCog(), getArea()
+  */
+  inline vpColVector get_nij() const
+  {
+    vpColVector nij(3);
+    nij[0] = mu20 / m00;
+    nij[1] = mu11 / m00;
+    nij[2] = mu02 / m00;
+
+    return nij;
+  }
+
   double getArea() const;
   /*!
 
@@ -247,10 +266,11 @@ public:
     moments are not computed.
 
     Computed moment are vpDot::m00, vpDot::m10, vpDot::m01, vpDot::m11,
-    vpDot::m20, vpDot::m02.
+    vpDot::m20, vpDot::m02 and second order centereed moments vpDot::mu11,
+    vpDot::mu20, vpDot::mu02 computed with respect to the blob centroid.
 
     The coordinates of the region's centroid (u, v) can be computed from the
-    moments by \f$u=\frac{m10}{m00}\f$ and  \f$v=\frac{m01}{m00}\f$.
+    moments by \f$u=\frac{m10}{m00}\f$ and \f$v=\frac{m01}{m00}\f$.
 
   */
   void setComputeMoments(bool activate) { compute_moment = activate; }
@@ -347,7 +367,11 @@ public:
   static void trackAndDisplay(vpDot2 dot[], const unsigned int &n, vpImage<unsigned char> &I,
                               std::vector<vpImagePoint> &cogs, vpImagePoint *cogStar = NULL);
 
+#ifdef VISP_BUILD_DEPRECATED_FUNCTIONS
 public:
+#else
+private:
+#endif
   double m00;  /*!< Considering the general distribution moments for \f$ N \f$
      points defined by the relation \f$ m_{ij} = \sum_{h=0}^{N}
      u_h^i v_h^j \f$, \f$ m_{00} \f$ is a zero order moment obtained
@@ -397,17 +421,17 @@ public:
 
      \sa setComputeMoments()
          */
-  double mu11; /*!< \f$ \mu_{11} \f$ is a second order central moments defined
+  double mu11; /*!< \f$ \mu_{11} \f$ is a second order centered moment defined
      by: \f$ \mu_{11} = m_{11} - \frac{m_{10}}{m_{00}}m_{01} \f$
 
      \sa setComputeMoments()
          */
-  double mu20; /*!< \f$ \mu_{20} \f$ is a second order central moments defined
+  double mu20; /*!< \f$ \mu_{20} \f$ is a second order centered moment defined
      by: \f$ \mu_{20} = m_{20} - \frac{m_{10}}{m_{00}}m_{10} \f$
 
      \sa setComputeMoments()
          */
-  double mu02; /*!< \f$ \mu_{02} \f$ is a second order central moments defined
+  double mu02; /*!< \f$ \mu_{02} \f$ is a second order centered moments defined
      by: \f$ \mu_{02} = m_{02} - \frac{m_{01}}{m_{00}}m_{01} \f$
 
      \sa setComputeMoments()
