@@ -102,9 +102,7 @@ int main()
   display.init(I,100,100,"Mb Hybrid Tracker");
 #endif
 
-#if defined VISP_HAVE_PUGIXML
   tracker.loadConfigFile("cube.xml"); // Load the configuration of the tracker
-#endif
   // Load the 3d model in cao format. No 3rd party library is required
   tracker.loadModel("cube.cao");
   // Get the camera parameters used by the tracker (from the configuration file).
@@ -149,9 +147,7 @@ int main()
   //acquire an image
   vpImageIo::read(I, "cube.pgm"); // Example of acquisition
 
-#if defined VISP_HAVE_PUGIXML
   tracker.loadConfigFile("cube.xml"); // Load the configuration of the tracker
-#endif
   // load the 3d model, to read .wrl model coin is required, if coin is not installed .cao file can be used.
   tracker.loadModel("cube.cao");
   tracker.initFromPose(I, cMo); // initialise the tracker with the given pose.
@@ -194,9 +190,7 @@ int main()
   display.init(I,100,100,"Mb Hybrid Tracker");
 #endif
 
-#if defined VISP_HAVE_PUGIXML
   tracker.loadConfigFile("cube.xml"); // Load the configuration of the tracker
-#endif
   tracker.getCameraParameters(cam); // Get the camera parameters used by the tracker (from the configuration file).
   // load the 3d model, to read .wrl model coin is required, if coin is not installed .cao file can be used.
   tracker.loadModel("cube.cao");
@@ -258,7 +252,7 @@ public:
    */
   virtual inline double getNearClippingDistance() const { return vpMbKltTracker::getNearClippingDistance(); }
 
-  virtual void loadConfigFile(const std::string &configFile);
+  virtual void loadConfigFile(const std::string &configFile, bool verbose=true);
 
   void reInitModel(const vpImage<unsigned char> &I, const std::string &cad_name, const vpHomogeneousMatrix &cMo,
                    bool verbose = false, const vpHomogeneousMatrix &T=vpHomogeneousMatrix());
