@@ -195,6 +195,25 @@ public:
   virtual void getMovingEdge(vpMe &me1, vpMe &me2) const;
   virtual void getMovingEdge(std::map<std::string, vpMe> &mapOfMovingEdges) const;
 
+  /*!
+   * Return the number of depth dense features taken into account in the virtual visual-servoing scheme.
+   */
+  virtual inline unsigned int getNbFeaturesDepthDense() const { return m_nb_feat_depthDense; }
+  /*!
+   * Return the number of depth normal features features taken into account in the virtual visual-servoing scheme.
+   */
+  virtual inline unsigned int getNbFeaturesDepthNormal() const { return m_nb_feat_depthNormal; }
+  /*!
+   * Return the number of moving-edges features taken into account in the virtual visual-servoing scheme.
+   *
+   * This function is similar to getNbPoints().
+   */
+  virtual inline unsigned int getNbFeaturesEdge() const { return m_nb_feat_edge; }
+  /*!
+   * Return the number of klt keypoints features taken into account in the virtual visual-servoing scheme.
+   */
+  virtual inline unsigned int getNbFeaturesKlt() const { return m_nb_feat_klt; }
+
   virtual unsigned int getNbPoints(unsigned int level = 0) const;
   virtual void getNbPoints(std::map<std::string, unsigned int> &mapOfNbPoints, unsigned int level = 0) const;
 
@@ -274,9 +293,9 @@ public:
   virtual void initFromPose(const std::map<std::string, const vpImage<vpRGBa> *> &mapOfColorImages,
                             const std::map<std::string, vpHomogeneousMatrix> &mapOfCameraPoses);
 
-  virtual void loadConfigFile(const std::string &configFile);
-  virtual void loadConfigFile(const std::string &configFile1, const std::string &configFile2);
-  virtual void loadConfigFile(const std::map<std::string, std::string> &mapOfConfigFiles);
+  virtual void loadConfigFile(const std::string &configFile, bool verbose=true);
+  virtual void loadConfigFile(const std::string &configFile1, const std::string &configFile2, bool verbose=true);
+  virtual void loadConfigFile(const std::map<std::string, std::string> &mapOfConfigFiles, bool verbose=true);
 
   virtual void loadModel(const std::string &modelFile, bool verbose = false, const vpHomogeneousMatrix &T=vpHomogeneousMatrix());
   virtual void loadModel(const std::string &modelFile1, const std::string &modelFile2, bool verbose = false,
@@ -534,7 +553,7 @@ private:
 
     virtual void init(const vpImage<unsigned char> &I);
 
-    virtual void loadConfigFile(const std::string &configFile);
+    virtual void loadConfigFile(const std::string &configFile, bool verbose=true);
 
     virtual void reInitModel(const vpImage<unsigned char> &I, const std::string &cad_name,
                              const vpHomogeneousMatrix &cMo, bool verbose = false,
@@ -654,5 +673,15 @@ protected:
   vpColVector m_w;
   //! Weighted error
   vpColVector m_weightedError;
+
+  //! Number of moving-edges features
+  unsigned int m_nb_feat_edge;
+  //! Number of klt features
+  unsigned int m_nb_feat_klt;
+  //! Number of depth normal features
+  unsigned int m_nb_feat_depthNormal;
+  //! Number of depth dense features
+  unsigned int m_nb_feat_depthDense;
+
 };
 #endif
