@@ -59,7 +59,6 @@ private:
 };
 #endif //#ifndef DOXYGEN_SHOULD_SKIP_THIS
 
-
 /*
  * The code bellow previously in vpMbtTuckeyEstimator.cpp produced
  * a link issue with MinGW-W64 x86_64-8.1.0-posix-seh-rt_v6-rev0 (g++ 8.1.0)
@@ -82,9 +81,6 @@ private:
 #define USE_TRANSFORM 1
 #if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11) && USE_TRANSFORM
 #define HAVE_TRANSFORM 1
-#endif
-
-#if HAVE_TRANSFORM
 #include <functional>
 #endif
 
@@ -102,17 +98,19 @@ private:
 #endif
 #endif
 
-#define USE_ORIGINAL_TUKEY_CODE 1
-
 #ifndef DOXYGEN_SHOULD_SKIP_THIS
 
 #if HAVE_TRANSFORM
 namespace
 {
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_14)
+auto AbsDiff = [](const auto &a, const auto &b) { return std::fabs(a - b); };
+#else
 template <typename T> struct AbsDiff : public std::binary_function<T, T, T> {
   T operator()(const T a, const T b) const { return std::fabs(a - b); }
 };
-}
+#endif
+} // namespace
 #endif
 
 template class vpMbtTukeyEstimator<float>;
@@ -126,7 +124,7 @@ inline __m128 abs_ps(__m128 x)
   static const __m128 sign_mask = _mm_set1_ps(-0.f); // -0.f = 1 << 31
   return _mm_andnot_ps(sign_mask, x);
 }
-}
+} // namespace
 #endif
 
 template <typename T> T vpMbtTukeyEstimator<T>::getMedian(std::vector<T> &vec)
@@ -157,8 +155,12 @@ void vpMbtTukeyEstimator<T>::MEstimator_impl(const std::vector<T> &residues, std
   m_normres.resize(residues.size());
 
 #if HAVE_TRANSFORM
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_14)
+  std::transform(residues.begin(), residues.end(), m_normres.begin(), std::bind(AbsDiff, std::placeholders::_1, med));
+#else
   std::transform(residues.begin(), residues.end(), m_normres.begin(),
                  std::bind(AbsDiff<T>(), std::placeholders::_1, med));
+#endif
 #else
   for (size_t i = 0; i < m_residues.size(); i++) {
     m_normres[i] = (std::fabs(residues[i] - med));
@@ -181,8 +183,8 @@ void vpMbtTukeyEstimator<T>::MEstimator_impl(const std::vector<T> &residues, std
 }
 
 template <>
-inline void vpMbtTukeyEstimator<float>::MEstimator_impl_ssse3(const std::vector<float> &residues, std::vector<float> &weights,
-                                                              const float NoiseThreshold)
+inline void vpMbtTukeyEstimator<float>::MEstimator_impl_ssse3(const std::vector<float> &residues,
+                                                              std::vector<float> &weights, const float NoiseThreshold)
 {
 #if VISP_HAVE_SSSE3
   if (residues.empty()) {
@@ -228,9 +230,13 @@ inline void vpMbtTukeyEstimator<float>::MEstimator_impl_ssse3(const std::vector<
 #endif
 }
 
+/*!
+ * \relates vpMbtTukeyEstimator
+ */
 template <>
 inline void vpMbtTukeyEstimator<double>::MEstimator_impl_ssse3(const std::vector<double> &residues,
-                                                               std::vector<double> &weights, const double NoiseThreshold)
+                                                               std::vector<double> &weights,
+                                                               const double NoiseThreshold)
 {
 #if VISP_HAVE_SSSE3
   if (residues.empty()) {
@@ -243,8 +249,12 @@ inline void vpMbtTukeyEstimator<double>::MEstimator_impl_ssse3(const std::vector
   m_normres.resize(residues.size());
 
 #if HAVE_TRANSFORM
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_14)
+  std::transform(residues.begin(), residues.end(), m_normres.begin(), std::bind(AbsDiff, std::placeholders::_1, med));
+#else
   std::transform(residues.begin(), residues.end(), m_normres.begin(),
                  std::bind(AbsDiff<double>(), std::placeholders::_1, med));
+#endif
 #else
   for (size_t i = 0; i < m_residues.size(); i++) {
     m_normres[i] = (std::fabs(residues[i] - med));
@@ -271,9 +281,12 @@ inline void vpMbtTukeyEstimator<double>::MEstimator_impl_ssse3(const std::vector
 #endif
 }
 
+/*!
+ * \relates vpMbtTukeyEstimator
+ */
 template <>
 inline void vpMbtTukeyEstimator<float>::MEstimator(const std::vector<float> &residues, std::vector<float> &weights,
-                                            const float NoiseThreshold)
+                                                   const float NoiseThreshold)
 {
   bool checkSSSE3 = vpCPUFeatures::checkSSSE3();
 #if !VISP_HAVE_SSSE3
@@ -286,9 +299,12 @@ inline void vpMbtTukeyEstimator<float>::MEstimator(const std::vector<float> &res
     MEstimator_impl(residues, weights, NoiseThreshold);
 }
 
+/*!
+ * \relates vpMbtTukeyEstimator
+ */
 template <>
 inline void vpMbtTukeyEstimator<double>::MEstimator(const std::vector<double> &residues, std::vector<double> &weights,
-                                             const double NoiseThreshold)
+                                                    const double NoiseThreshold)
 {
   bool checkSSSE3 = vpCPUFeatures::checkSSSE3();
 #if !VISP_HAVE_SSSE3
@@ -301,44 +317,31 @@ inline void vpMbtTukeyEstimator<double>::MEstimator(const std::vector<double> &r
     MEstimator_impl(residues, weights, NoiseThreshold);
 }
 
+/*!
+ * Consider Tukey influence function.
+ */
 template <typename T> void vpMbtTukeyEstimator<T>::psiTukey(const T sig, std::vector<T> &x, vpColVector &weights)
 {
-  T cst_const = static_cast<T>(4.6851);
-  T inv_cst_const = 1 / cst_const;
-  T inv_sig = 1 / sig;
+  double C = sig * 4.6851;
 
+  // Here we consider that sig cannot be equal to 0
   for (unsigned int i = 0; i < (unsigned int)x.size(); i++) {
-#if USE_ORIGINAL_TUKEY_CODE
-    if (std::fabs(sig) <= std::numeric_limits<T>::epsilon() &&
-        std::fabs(weights[i]) > std::numeric_limits<double>::epsilon() // sig should be equal to 0
-                                                                       // only if NoiseThreshold
-                                                                       // ==
-                                                                       // 0
-    ) {
-      weights[i] = 1;
-      continue;
-    }
-#endif
+    double xi = x[i] / C;
+    xi *= xi;
 
-    double xi_sig = x[(size_t)i] * inv_sig;
-
-    if ((std::fabs(xi_sig) <= cst_const)
-#if USE_ORIGINAL_TUKEY_CODE
-        && std::fabs(weights[i]) > std::numeric_limits<double>::epsilon() // Consider the previous
-                                                                          // weights here
-#endif
-    ) {
-      weights[i] = (1 - (xi_sig * inv_cst_const) * (xi_sig * inv_cst_const)) *
-                   (1 - (xi_sig * inv_cst_const) * (xi_sig * inv_cst_const)); // vpMath::sqr( 1 -
-                                                                              // vpMath::sqr(xi_sig *
-                                                                              // inv_cst_const) );
-    } else {
-      // Outlier - could resize list of points tracked here?
+    if (xi > 1.) {
       weights[i] = 0;
+    } else {
+      xi = 1 - xi;
+      xi *= xi;
+      weights[i] = xi;
     }
   }
 }
 
+/*!
+ * \relates vpMbtTukeyEstimator
+ */
 template <>
 inline void vpMbtTukeyEstimator<double>::MEstimator(const vpColVector &residues, vpColVector &weights,
                                                     const double NoiseThreshold)
@@ -373,6 +376,9 @@ inline void vpMbtTukeyEstimator<double>::MEstimator(const vpColVector &residues,
   psiTukey(sigma, m_normres, weights);
 }
 
+/*!
+ * \relates vpMbtTukeyEstimator
+ */
 template <>
 inline void vpMbtTukeyEstimator<float>::MEstimator(const vpColVector &residues, vpColVector &weights,
                                                    const double NoiseThreshold)
@@ -409,37 +415,25 @@ inline void vpMbtTukeyEstimator<float>::MEstimator(const vpColVector &residues,
   psiTukey(sigma, m_normres, weights);
 }
 
+/*!
+ * Consider Tukey influence function.
+ */
 template <class T> void vpMbtTukeyEstimator<T>::psiTukey(const T sig, std::vector<T> &x, std::vector<T> &weights)
 {
-  T cst_const = static_cast<T>(4.6851);
-  T inv_cst_const = 1 / cst_const;
-  T inv_sig = 1 / sig;
+  T C = static_cast<T>(4.6851) * sig;
+  weights.resize(x.size());
 
+  // Here we consider that sig cannot be equal to 0
   for (size_t i = 0; i < x.size(); i++) {
-#if USE_ORIGINAL_TUKEY_CODE
-    if (std::fabs(sig) <= std::numeric_limits<T>::epsilon() &&
-        std::fabs(weights[i]) > std::numeric_limits<T>::epsilon() // sig should be equal to 0 only
-                                                                  // if NoiseThreshold == 0
-    ) {
-      weights[i] = 1;
-      continue;
-    }
-#endif
+    T xi = x[i] / C;
+    xi *= xi;
 
-    T xi_sig = x[i] * inv_sig;
-
-    if ((std::fabs(xi_sig) <= cst_const)
-#if USE_ORIGINAL_TUKEY_CODE
-        && std::fabs(weights[i]) > std::numeric_limits<T>::epsilon() // Consider the previous
-                                                                     // weights here
-#endif
-    ) {
-      // vpMath::sqr( 1 - vpMath::sqr(xi_sig * inv_cst_const) );
-      weights[i] = (1 - (xi_sig * inv_cst_const) * (xi_sig * inv_cst_const)) *
-                   (1 - (xi_sig * inv_cst_const) * (xi_sig * inv_cst_const));
-    } else {
-      // Outlier - could resize list of points tracked here?
+    if (xi > 1.) {
       weights[i] = 0;
+    } else {
+      xi = 1 - xi;
+      xi *= xi;
+      weights[i] = xi;
     }
   }
 }
