@@ -36,6 +36,10 @@
 #include <visp3/core/vpCPUFeatures.h>
 #include <visp3/mbt/vpMbtFaceDepthDense.h>
 
+#ifdef VISP_HAVE_PCL
+#include <pcl/common/point_tests.h>
+#endif
+
 #if defined __SSE2__ || defined _M_X64 || (defined _M_IX86_FP && _M_IX86_FP >= 2)
 #include <emmintrin.h>
 #define VISP_HAVE_SSE2 1
@@ -74,10 +78,11 @@ vpMbtFaceDepthDense::~vpMbtFaceDepthDense()
   \param P1 : The first extremity of the line.
   \param P2 : The second extremity of the line.
   \param faces : Pointer to vpMbHiddenFaces.
+  \param rand_gen : Random number generator used in vpMbtDistanceLine::buildFrom().
   \param polygon : The index of the polygon to which the line belongs.
   \param name : the optional name of the line
 */
-void vpMbtFaceDepthDense::addLine(vpPoint &P1, vpPoint &P2, vpMbHiddenFaces<vpMbtPolygon> *const faces, int polygon,
+void vpMbtFaceDepthDense::addLine(vpPoint &P1, vpPoint &P2, vpMbHiddenFaces<vpMbtPolygon> *const faces, vpUniRand& rand_gen, int polygon,
                                   std::string name)
 {
   // Build a PolygonLine to be able to easily display the lines model
@@ -116,7 +121,7 @@ void vpMbtFaceDepthDense::addLine(vpPoint &P1, vpPoint &P2, vpMbHiddenFaces<vpMb
     l = new vpMbtDistanceLine;
 
     l->setCameraParameters(m_cam);
-    l->buildFrom(P1, P2);
+    l->buildFrom(P1, P2, rand_gen);
     l->addPolygon(polygon);
     l->hiddenface = faces;
     l->useScanLine = m_useScanLine;
