@@ -169,9 +169,9 @@ bool vpMbtDistanceCircle::initMovingEdge(const vpImage<unsigned char> &I, const
 
     try {
       vpImagePoint ic;
-      double mu20_p, mu11_p, mu02_p;
-      vpMeterPixelConversion::convertEllipse(cam, *circle, ic, mu20_p, mu11_p, mu02_p);
-      meEllipse->initTracking(I, ic, mu20_p, mu11_p, mu02_p, doNotTrack);
+      double n20_p, n11_p, n02_p;
+      vpMeterPixelConversion::convertEllipse(cam, *circle, ic, n20_p, n11_p, n02_p);
+      meEllipse->initTracking(I, ic, n20_p, n11_p, n02_p, doNotTrack);
     } catch (...) {
       // vpTRACE("the circle can't be initialized");
       return false;
@@ -225,9 +225,9 @@ void vpMbtDistanceCircle::updateMovingEdge(const vpImage<unsigned char> &I, cons
     try {
 
       vpImagePoint ic;
-      double mu20_p, mu11_p, mu02_p;
-      vpMeterPixelConversion::convertEllipse(cam, *circle, ic, mu20_p, mu11_p, mu02_p);
-      meEllipse->updateParameters(I, ic, mu20_p, mu11_p, mu02_p);
+      double n20_p, n11_p, n02_p;
+      vpMeterPixelConversion::convertEllipse(cam, *circle, ic, n20_p, n11_p, n02_p);
+      meEllipse->updateParameters(I, ic, n20_p, n11_p, n02_p);
     } catch (...) {
       Reinit = true;
     }
@@ -276,10 +276,10 @@ void vpMbtDistanceCircle::display(const vpImage<unsigned char> &I, const vpHomog
   std::vector<double> params = getModelForDisplay(cMo, camera, displayFullModel);
 
   vpImagePoint center(params[0], params[1]);
-  double mu20_p = params[2];
-  double mu11_p = params[3];
-  double mu02_p = params[4];
-  vpDisplay::displayEllipse(I, center, mu20_p, mu11_p, mu02_p, true, col, thickness);
+  double n20_p = params[2];
+  double n11_p = params[3];
+  double n02_p = params[4];
+  vpDisplay::displayEllipse(I, center, n20_p, n11_p, n02_p, true, col, thickness);
 }
 
 /*!
@@ -300,10 +300,10 @@ void vpMbtDistanceCircle::display(const vpImage<vpRGBa> &I, const vpHomogeneousM
   std::vector<double> params = getModelForDisplay(cMo, camera, displayFullModel);
 
   vpImagePoint center(params[1], params[2]);
-  double mu20_p = params[3];
-  double mu11_p = params[4];
-  double mu02_p = params[5];
-  vpDisplay::displayEllipse(I, center, mu20_p, mu11_p, mu02_p, true, col, thickness);
+  double n20_p = params[3];
+  double n11_p = params[4];
+  double n02_p = params[5];
+  vpDisplay::displayEllipse(I, center, n20_p, n11_p, n02_p, true, col, thickness);
 }
 
 /*!
@@ -339,7 +339,9 @@ std::vector<std::vector<double> > vpMbtDistanceCircle::getFeaturesForDisplay()
 /*!
   Return a list of ellipse parameters to display the primitive at a given pose and camera parameters.
   - Parameters are: `<primitive id (here 1 for ellipse)>`, `<pt_center.i()>`, `<pt_center.j()>`,
-  `<mu20>`, `<mu11>`, `<mu02>`
+  `<n20>`, `<n11>`, `<n02>` which are respectively the ellipse centroid coordinates and
+  second order centered moments of the ellipse normalized by its area (i.e., such that \f$n_{ij} = \mu_{ij}/a\f$
+  where \f$\mu_{ij}\f$ are the centered moments and a the area).
 
   \param cMo : Pose used to project the 3D model into the image.
   \param camera : The camera parameters.
@@ -362,14 +364,14 @@ std::vector<double> vpMbtDistanceCircle::getModelForDisplay(const vpHomogeneousM
     }
 
     vpImagePoint center;
-    double mu20_p, mu11_p, mu02_p;
-    vpMeterPixelConversion::convertEllipse(camera, *circle, center, mu20_p, mu11_p, mu02_p);
+    double n20_p, n11_p, n02_p;
+    vpMeterPixelConversion::convertEllipse(camera, *circle, center, n20_p, n11_p, n02_p);
     params.push_back(1); //1 for ellipse parameters
     params.push_back(center.get_i());
     params.push_back(center.get_j());
-    params.push_back(mu20_p);
-    params.push_back(mu11_p);
-    params.push_back(mu02_p);
+    params.push_back(n20_p);
+    params.push_back(n11_p);
+    params.push_back(n02_p);
   }
 
   return params;
@@ -442,27 +444,27 @@ void vpMbtDistanceCircle::computeInteractionMatrixError(const vpHomogeneousMatri
     // Get the parameters of the ellipse in the image plane
     double xg = circle->p[0];
     double yg = circle->p[1];
-    double mu20 = circle->p[2];
-    double mu11 = circle->p[3];
-    double mu02 = circle->p[4];
+    double n20 = circle->p[2];
+    double n11 = circle->p[3];
+    double n02 = circle->p[4];
 
     unsigned int j = 0;
 
     for (std::list<vpMeSite>::const_iterator it = meEllipse->getMeList().begin(); it != meEllipse->getMeList().end();
          ++it) {
       vpPixelMeterConversion::convertPoint(cam, it->j, it->i, x, y);
-      H[0] = 2 * (mu11 * (y - yg) + mu02 * (xg - x));
-      H[1] = 2 * (mu20 * (yg - y) + mu11 * (x - xg));
-      H[2] = vpMath::sqr(y - yg) - mu02;
-      H[3] = 2 * (yg * (x - xg) + y * xg + mu11 - x * y);
-      H[4] = vpMath::sqr(x - xg) - mu20;
+      H[0] = 2 * (n11 * (y - yg) + n02 * (xg - x));
+      H[1] = 2 * (n20 * (yg - y) + n11 * (x - xg));
+      H[2] = vpMath::sqr(y - yg) - n02;
+      H[3] = 2 * (yg * (x - xg) + y * xg + n11 - x * y);
+      H[4] = vpMath::sqr(x - xg) - n20;
 
       for (unsigned int k = 0; k < 6; k++)
         L[j][k] = H[0] * H1[0][k] + H[1] * H1[1][k] + H[2] * H1[2][k] + H[3] * H1[3][k] + H[4] * H1[4][k];
 
-      error[j] = mu02 * vpMath::sqr(x) + mu20 * vpMath::sqr(y) - 2 * mu11 * x * y + 2 * (mu11 * yg - mu02 * xg) * x +
-                 2 * (mu11 * xg - mu20 * yg) * y + mu02 * vpMath::sqr(xg) + mu20 * vpMath::sqr(yg) -
-                 2 * mu11 * xg * yg + vpMath::sqr(mu11) - mu20 * mu02;
+      error[j] = n02 * vpMath::sqr(x) + n20 * vpMath::sqr(y) - 2 * n11 * x * y + 2 * (n11 * yg - n02 * xg) * x +
+                 2 * (n11 * xg - n20 * yg) * y + n02 * vpMath::sqr(xg) + n20 * vpMath::sqr(yg) -
+                 2 * n11 * xg * yg + vpMath::sqr(n11) - n20 * n02;
 
       j++;
     }
