@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -39,6 +39,7 @@
 
 #include <visp3/core/vpPolygon.h>
 #include <visp3/mbt/vpMbtDistanceKltPoints.h>
+#include <visp3/me/vpMeTracker.h>
 
 #if defined(VISP_HAVE_MODULE_KLT) && (defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100))
 
@@ -74,8 +75,9 @@ vpMbtDistanceKltPoints::~vpMbtDistanceKltPoints() {}
   points that are indeed in the face.
 
   \param _tracker : ViSP OpenCV KLT Tracker.
+  \param mask: Mask image or NULL if not wanted. Mask values that are set to true are considered in the tracking. To disable a pixel, set false.
 */
-void vpMbtDistanceKltPoints::init(const vpKltOpencv &_tracker)
+void vpMbtDistanceKltPoints::init(const vpKltOpencv &_tracker, const vpImage<bool> *mask)
 {
   // extract ids of the points in the face
   nbPointsInit = 0;
@@ -93,14 +95,18 @@ void vpMbtDistanceKltPoints::init(const vpKltOpencv &_tracker)
 
     bool add = false;
 
-    if (useScanLine) {
-      if ((unsigned int)y_tmp < hiddenface->getMbScanLineRenderer().getPrimitiveIDs().getHeight() &&
+    // Add points inside visibility mask only
+    if (vpMeTracker::inMask(mask, (unsigned int) y_tmp, (unsigned int) x_tmp)) {
+      if (useScanLine) {
+        if ((unsigned int)y_tmp < hiddenface->getMbScanLineRenderer().getPrimitiveIDs().getHeight() &&
           (unsigned int)x_tmp < hiddenface->getMbScanLineRenderer().getPrimitiveIDs().getWidth() &&
           hiddenface->getMbScanLineRenderer().getPrimitiveIDs()[(unsigned int)y_tmp][(unsigned int)x_tmp] ==
-              polygon->getIndex())
+          polygon->getIndex())
+          add = true;
+      }
+      else if (vpPolygon::isInside(roi, y_tmp, x_tmp)) {
         add = true;
-    } else if (vpPolygon::isInside(roi, y_tmp, x_tmp)) {
-      add = true;
+      }
     }
 
     if (add) {
@@ -142,8 +148,9 @@ void vpMbtDistanceKltPoints::init(const vpKltOpencv &_tracker)
   \param _tracker : the KLT tracker
   \return the number of points that are tracked in this face and in this
   instanciation of the tracker
+  \param mask: Mask image or NULL if not wanted. Mask values that are set to true are considered in the tracking. To disable a pixel, set false.
 */
-unsigned int vpMbtDistanceKltPoints::computeNbDetectedCurrent(const vpKltOpencv &_tracker)
+unsigned int vpMbtDistanceKltPoints::computeNbDetectedCurrent(const vpKltOpencv &_tracker, const vpImage<bool> *mask)
 {
   long id;
   float x, y;
@@ -153,7 +160,7 @@ unsigned int vpMbtDistanceKltPoints::computeNbDetectedCurrent(const vpKltOpencv
 
   for (unsigned int i = 0; i < static_cast<unsigned int>(_tracker.getNbFeatures()); i++) {
     _tracker.getFeature((int)i, id, x, y);
-    if (isTrackedFeature((int)id)) {
+    if (isTrackedFeature((int)id) && vpMeTracker::inMask(mask, (unsigned int) y, (unsigned int) x)) {
 #if TARGET_OS_IPHONE
       curPoints[(int)id] = vpImagePoint(static_cast<double>(y), static_cast<double>(x));
       curPointsInd[(int)id] = (int)i;
@@ -226,7 +233,7 @@ void vpMbtDistanceKltPoints::computeInteractionMatrixAndResidu(vpColVector &_R,
   }
 }
 
-double vpMbtDistanceKltPoints::compute_1_over_Z(const double x, const double y)
+double vpMbtDistanceKltPoints::compute_1_over_Z(double x, double y)
 {
   double num = cRc0_0n[0] * x + cRc0_0n[1] * y + cRc0_0n[2];
   double den = -(d0 - dt);
@@ -245,7 +252,7 @@ double vpMbtDistanceKltPoints::compute_1_over_Z(const double x, const double y)
   \param y_out : the y coordinates of the output point
   \param _cHc0 : the homography used to transfer the point
 */
-inline void vpMbtDistanceKltPoints::computeP_mu_t(const double x_in, const double y_in, double &x_out, double &y_out,
+inline void vpMbtDistanceKltPoints::computeP_mu_t(double x_in, double y_in, double &x_out, double &y_out,
                                                   const vpMatrix &_cHc0)
 {
   double p_mu_t_2 = x_in * _cHc0[2][0] + y_in * _cHc0[2][1] + _cHc0[2][2];
@@ -261,17 +268,17 @@ inline void vpMbtDistanceKltPoints::computeP_mu_t(const double x_in, const doubl
 }
 
 /*!
-  compute the homography using a displacement matrix.
+  Compute the homography using a displacement matrix.
 
   the homography is given by:
 
   \f$ {}^cH_{c_0} = {}^cR_{c_0} + \frac{{}^cT_{c_0} . {}^tN}{d_0} \f$
 
-  Several internal variables are computed (dt, cRc0_0n)
+  Several internal variables are computed (dt, cRc0_0n).
 
-  \param _cTc0 : the displacement matrix of the camera between the initial
-  position of the camera and the current camera position \param _cHc0 : the
-  homography of the plane
+  \param _cTc0 : The displacement matrix of the camera between the initial
+  position of the camera and the current camera position
+  \param _cHc0 : The homography of the plane.
 */
 void vpMbtDistanceKltPoints::computeHomography(const vpHomogeneousMatrix &_cTc0, vpHomography &_cHc0)
 {
@@ -318,7 +325,7 @@ void vpMbtDistanceKltPoints::computeHomography(const vpHomogeneousMatrix &_cTc0,
   \param _id : the id of the current feature to test
   \return true if the id is in the list of tracked feature
 */
-bool vpMbtDistanceKltPoints::isTrackedFeature(const int _id)
+bool vpMbtDistanceKltPoints::isTrackedFeature(int _id)
 {
   //   std::map<int, vpImagePoint>::const_iterator iter = initPoints.begin();
   //   while(iter != initPoints.end()){
@@ -579,46 +586,88 @@ void vpMbtDistanceKltPoints::displayPrimitive(const vpImage<vpRGBa> &_I)
 }
 
 void vpMbtDistanceKltPoints::display(const vpImage<unsigned char> &I, const vpHomogeneousMatrix & /*cMo*/,
-                                     const vpCameraParameters &camera, const vpColor &col, const unsigned int thickness,
-                                     const bool displayFullModel)
+                                     const vpCameraParameters &camera, const vpColor &col, unsigned int thickness,
+                                     bool displayFullModel)
 {
-  if ((polygon->isVisible() && isTrackedKltPoints) || displayFullModel) {
-    std::vector<std::pair<vpPoint, unsigned int> > roi;
-    polygon->getPolygonClipped(roi);
+  std::vector<std::vector<double> > models = getModelForDisplay(camera, displayFullModel);
 
-    for (unsigned int j = 0; j < roi.size(); j += 1) {
-      if (((roi[(j + 1) % roi.size()].second & roi[j].second & vpPolygon3D::NEAR_CLIPPING) == 0) &&
-          ((roi[(j + 1) % roi.size()].second & roi[j].second & vpPolygon3D::FAR_CLIPPING) == 0) &&
-          ((roi[(j + 1) % roi.size()].second & roi[j].second & vpPolygon3D::DOWN_CLIPPING) == 0) &&
-          ((roi[(j + 1) % roi.size()].second & roi[j].second & vpPolygon3D::UP_CLIPPING) == 0) &&
-          ((roi[(j + 1) % roi.size()].second & roi[j].second & vpPolygon3D::LEFT_CLIPPING) == 0) &&
-          ((roi[(j + 1) % roi.size()].second & roi[j].second & vpPolygon3D::RIGHT_CLIPPING) == 0)) {
+  for (size_t i = 0; i < models.size(); i++) {
+    vpImagePoint ip1(models[i][1], models[i][2]);
+    vpImagePoint ip2(models[i][3], models[i][4]);
 
-        vpImagePoint ip1, ip2;
-        std::vector<std::pair<vpPoint, vpPoint> > linesLst;
-
-        if (useScanLine && !displayFullModel)
-          hiddenface->computeScanLineQuery(roi[j].first, roi[(j + 1) % roi.size()].first, linesLst, true);
-        else
-          linesLst.push_back(std::make_pair(roi[j].first, roi[(j + 1) % roi.size()].first));
-
-        for (unsigned int i = 0; i < linesLst.size(); i++) {
-          linesLst[i].first.project();
-          linesLst[i].second.project();
-          vpMeterPixelConversion::convertPoint(camera, linesLst[i].first.get_x(), linesLst[i].first.get_y(), ip1);
-          vpMeterPixelConversion::convertPoint(camera, linesLst[i].second.get_x(), linesLst[i].second.get_y(), ip2);
-
-          vpDisplay::displayLine(I, ip1, ip2, col, thickness);
-        }
-      }
-    }
+    vpDisplay::displayLine(I, ip1, ip2, col, thickness);
   }
 }
 
 void vpMbtDistanceKltPoints::display(const vpImage<vpRGBa> &I, const vpHomogeneousMatrix & /*cMo*/,
-                                     const vpCameraParameters &camera, const vpColor &col, const unsigned int thickness,
-                                     const bool displayFullModel)
+                                     const vpCameraParameters &camera, const vpColor &col, unsigned int thickness,
+                                     bool displayFullModel)
 {
+  std::vector<std::vector<double> > models = getModelForDisplay(camera, displayFullModel);
+
+  for (size_t i = 0; i < models.size(); i++) {
+    vpImagePoint ip1(models[i][1], models[i][2]);
+    vpImagePoint ip2(models[i][3], models[i][4]);
+
+    vpDisplay::displayLine(I, ip1, ip2, col, thickness);
+  }
+}
+
+/*!
+  Return a list of features parameters for display.
+  - Parameters are: `<feature id (here 1 for KLT)>`, `<pt.i()>`, `<pt.j()>`,
+  `<klt_id.i()>`, `<klt_id.j()>`, `<klt_id.id>`
+*/
+std::vector<std::vector<double> > vpMbtDistanceKltPoints::getFeaturesForDisplay()
+{
+  std::vector<std::vector<double> > features;
+
+  std::map<int, vpImagePoint>::const_iterator iter = curPoints.begin();
+  for (; iter != curPoints.end(); ++iter) {
+    int id(iter->first);
+    vpImagePoint iP;
+    iP.set_i(static_cast<double>(iter->second.get_i()));
+    iP.set_j(static_cast<double>(iter->second.get_j()));
+
+    vpImagePoint iP2;
+    iP2.set_i(vpMath::round(iP.get_i() + 7));
+    iP2.set_j(vpMath::round(iP.get_j() + 7));
+
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
+    std::vector<double> params = {1, //KLT
+                                  iP.get_i(),
+                                  iP.get_j(),
+                                  iP2.get_i(),
+                                  iP2.get_j(),
+                                  static_cast<double>(id)};
+#else
+    std::vector<double> params;
+    params.push_back(1); //KLT
+    params.push_back(iP.get_i());
+    params.push_back(iP.get_j());
+    params.push_back(iP2.get_i());
+    params.push_back(iP2.get_j());
+    params.push_back(static_cast<double>(id));
+#endif
+    features.push_back(params);
+  }
+
+  return features;
+}
+
+/*!
+  Return a list of line parameters to display the primitive at a given pose and camera parameters.
+  Parameters are: <primitive id (here 0 for line)>, <pt_start.i()>, <pt_start.j()>
+                  <pt_end.i()>, <pt_end.j()>
+
+  \param camera : The camera parameters.
+  \param displayFullModel : If true, the line is displayed even if it is not
+*/
+std::vector<std::vector<double> > vpMbtDistanceKltPoints::getModelForDisplay(const vpCameraParameters &camera,
+                                                                             bool displayFullModel)
+{
+  std::vector<std::vector<double> > models;
+
   if ((polygon->isVisible() && isTrackedKltPoints) || displayFullModel) {
     std::vector<std::pair<vpPoint, unsigned int> > roi;
     polygon->getPolygonClipped(roi);
@@ -645,11 +694,27 @@ void vpMbtDistanceKltPoints::display(const vpImage<vpRGBa> &I, const vpHomogeneo
           vpMeterPixelConversion::convertPoint(camera, linesLst[i].first.get_x(), linesLst[i].first.get_y(), ip1);
           vpMeterPixelConversion::convertPoint(camera, linesLst[i].second.get_x(), linesLst[i].second.get_y(), ip2);
 
-          vpDisplay::displayLine(I, ip1, ip2, col, thickness);
+#if (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
+          std::vector<double> params = {0, //0 for line parameters
+                                        ip1.get_i(),
+                                        ip1.get_j(),
+                                        ip2.get_i(),
+                                        ip2.get_j()};
+#else
+          std::vector<double> params;
+          params.push_back(0); //0 for line parameters
+          params.push_back(ip1.get_i());
+          params.push_back(ip1.get_j());
+          params.push_back(ip2.get_i());
+          params.push_back(ip2.get_j());
+#endif
+          models.push_back(params);
         }
       }
     }
   }
+
+  return models;
 }
 
 #elif !defined(VISP_BUILD_SHARED_LIBS)
