@@ -86,49 +86,49 @@
 
 /*!
   \class vpKeyPoint
-  \ingroup group_vision_keypoints
+  \ingroup group_vision_keypoints group_detection_keypoint group_detection_mbt_object
 
   \brief Class that allows keypoints detection (and descriptors extraction)
-and matching thanks to OpenCV library. Thus to enable this class OpenCV should
-be installed. Installation instructions are provided here
-https://visp.inria.fr/3rd_opencv.
+  and matching thanks to OpenCV library. Thus to enable this class OpenCV should
+  be installed. Installation instructions are provided here
+  https://visp.inria.fr/3rd_opencv.
 
   This class permits to use different types of detectors, extractors and
-matchers easily. So, the classical SIFT and SURF keypoints could be used, as
-well as ORB, FAST, (etc.) keypoints, depending of the version of OpenCV you
-use.
+  matchers easily. So, the classical SIFT and SURF keypoints could be used, as
+  well as ORB, FAST, (etc.) keypoints, depending of the version of OpenCV you
+  use.
 
   \note Due to some patents, SIFT and SURF are packaged in an external module
-called nonfree module in OpenCV version before 3.0.0 and in xfeatures2d
-from 3.0.0. You have to check you have the corresponding module to use SIFT
-and SURF.
+  called nonfree module in OpenCV version before 3.0.0 and in xfeatures2d
+  from 3.0.0. You have to check you have the corresponding module to use SIFT
+  and SURF.
 
   The goal of this class is to provide a tool to match reference keypoints
-from a reference image (or train keypoints in OpenCV terminology) and detected
-keypoints from a current image (or query keypoints in OpenCV terminology).
+  from a reference image (or train keypoints in OpenCV terminology) and detected
+  keypoints from a current image (or query keypoints in OpenCV terminology).
 
   If you supply the corresponding 3D coordinates corresponding to the 2D
-coordinates of the reference keypoints, you can also estimate the pose of the
-object by matching a set of detected keypoints in the current image with the
-reference keypoints.
+  coordinates of the reference keypoints, you can also estimate the pose of the
+  object by matching a set of detected keypoints in the current image with the
+  reference keypoints.
 
   If you use this class, the first thing you have to do is to build
   the reference keypoints by detecting keypoints in a reference image which
-contains the object to detect. Then you match keypoints detected in a current
-image with those detected in a reference image by calling matchPoint()
-methods. You can access to the lists of matched points thanks to the methods
-getMatchedPointsInReferenceImage() and getMatchedPointsInCurrentImage(). These
-two methods return a list of matched points. The nth element of the first list
-is matched with the nth element of the second list. To provide easy
-compatibility with OpenCV terminology, getTrainKeyPoints() give you access to
-the list of keypoints detected in train images (or reference images) and
-getQueryKeyPoints() give you access to the list of keypoints detected in a
-query image (or current image). The method getMatches() give you access to a
-list of cv::DMatch with the correspondence between the index of the train
-keypoints and the index of the query keypoints.
+  contains the object to detect. Then you match keypoints detected in a current
+  image with those detected in a reference image by calling matchPoint()
+  methods. You can access to the lists of matched points thanks to the methods
+  getMatchedPointsInReferenceImage() and getMatchedPointsInCurrentImage(). These
+  two methods return a list of matched points. The nth element of the first list
+  is matched with the nth element of the second list. To provide easy
+  compatibility with OpenCV terminology, getTrainKeyPoints() give you access to
+  the list of keypoints detected in train images (or reference images) and
+  getQueryKeyPoints() give you access to the list of keypoints detected in a
+  query image (or current image). The method getMatches() give you access to a
+  list of cv::DMatch with the correspondence between the index of the train
+  keypoints and the index of the query keypoints.
 
   The following small example shows how to use the class to do the matching
-between current and reference keypoints.
+  between current and reference keypoints.
 
   \code
 #include <visp3/core/vpImage.h>
@@ -163,8 +163,8 @@ int main()
   \endcode
 
   It is also possible to build the reference keypoints in a region of interest
-(ROI) of an image and find keypoints to match in only a part of the current
-image. The small following example shows how to do this:
+  (ROI) of an image and find keypoints to match in only a part of the current
+  image. The small following example shows how to do this:
 
   \code
 #include <visp3/core/vpDisplay.h>
@@ -266,8 +266,11 @@ public:
 #if (VISP_HAVE_OPENCV_VERSION < 0x030000) || (defined(VISP_HAVE_OPENCV_XFEATURES2D))
     DETECTOR_STAR,
 #endif
-#if defined(VISP_HAVE_OPENCV_NONFREE) || defined(VISP_HAVE_OPENCV_XFEATURES2D)
+#if defined(VISP_HAVE_OPENCV_NONFREE) || defined(VISP_HAVE_OPENCV_XFEATURES2D) || \
+    (VISP_HAVE_OPENCV_VERSION >= 0x030411 && CV_MAJOR_VERSION < 4) || (VISP_HAVE_OPENCV_VERSION >= 0x040400)
     DETECTOR_SIFT,
+#endif
+#if defined(VISP_HAVE_OPENCV_NONFREE) || defined(VISP_HAVE_OPENCV_XFEATURES2D)
     DETECTOR_SURF,
 #endif
 #if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
@@ -291,8 +294,11 @@ public:
     DESCRIPTOR_FREAK,
     DESCRIPTOR_BRIEF,
 #endif
-#if defined(VISP_HAVE_OPENCV_NONFREE) || defined(VISP_HAVE_OPENCV_XFEATURES2D)
+#if defined(VISP_HAVE_OPENCV_NONFREE) || defined(VISP_HAVE_OPENCV_XFEATURES2D) || \
+    (VISP_HAVE_OPENCV_VERSION >= 0x030411 && CV_MAJOR_VERSION < 4) || (VISP_HAVE_OPENCV_VERSION >= 0x040400)
     DESCRIPTOR_SIFT,
+#endif
+#if defined(VISP_HAVE_OPENCV_NONFREE) || defined(VISP_HAVE_OPENCV_XFEATURES2D)
     DESCRIPTOR_SURF,
 #endif
 #if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
@@ -325,22 +331,22 @@ public:
                               unsigned int width);
   unsigned int buildReference(const vpImage<unsigned char> &I, const vpRect &rectangle);
 
-  void buildReference(const vpImage<unsigned char> &I, std::vector<cv::KeyPoint> &trainKeyPoint,
-                      std::vector<cv::Point3f> &points3f, bool append = false, int class_id = -1);
-  void buildReference(const vpImage<unsigned char> &I, const std::vector<cv::KeyPoint> &trainKeyPoint,
-                      const cv::Mat &trainDescriptors, const std::vector<cv::Point3f> &points3f,
-                      bool append = false, int class_id = -1);
+  unsigned int buildReference(const vpImage<unsigned char> &I, std::vector<cv::KeyPoint> &trainKeyPoints,
+                              std::vector<cv::Point3f> &points3f, bool append = false, int class_id = -1);
+  unsigned int buildReference(const vpImage<unsigned char> &I, const std::vector<cv::KeyPoint> &trainKeyPoints,
+                              const cv::Mat &trainDescriptors, const std::vector<cv::Point3f> &points3f,
+                              bool append = false, int class_id = -1);
 
   unsigned int buildReference(const vpImage<vpRGBa> &I_color);
   unsigned int buildReference(const vpImage<vpRGBa> &I_color, const vpImagePoint &iP, unsigned int height,
                               unsigned int width);
   unsigned int buildReference(const vpImage<vpRGBa> &I_color, const vpRect &rectangle);
 
-  void buildReference(const vpImage<vpRGBa> &I_color, std::vector<cv::KeyPoint> &trainKeyPoint,
-                      std::vector<cv::Point3f> &points3f, bool append = false, int class_id = -1);
-  void buildReference(const vpImage<vpRGBa> &I, const std::vector<cv::KeyPoint> &trainKeyPoint,
-                      const cv::Mat &trainDescriptors, const std::vector<cv::Point3f> &points3f,
-                      bool append = false, int class_id = -1);
+  unsigned int buildReference(const vpImage<vpRGBa> &I_color, std::vector<cv::KeyPoint> &trainKeyPoints,
+                              std::vector<cv::Point3f> &points3f, bool append = false, int class_id = -1);
+  unsigned int buildReference(const vpImage<vpRGBa> &I, const std::vector<cv::KeyPoint> &trainKeyPoints,
+                              const cv::Mat &trainDescriptors, const std::vector<cv::Point3f> &points3f,
+                              bool append = false, int class_id = -1);
 
   static void compute3D(const cv::KeyPoint &candidate, const std::vector<vpPoint> &roi, const vpCameraParameters &cam,
                         const vpHomogeneousMatrix &cMo, cv::Point3f &point);
@@ -656,8 +662,8 @@ public:
    */
   inline cv::Mat getQueryDescriptors() const { return m_queryDescriptors; }
 
-  void getQueryKeyPoints(std::vector<cv::KeyPoint> &keyPoints) const;
-  void getQueryKeyPoints(std::vector<vpImagePoint> &keyPoints) const;
+  void getQueryKeyPoints(std::vector<cv::KeyPoint> &keyPoints, bool matches = true) const;
+  void getQueryKeyPoints(std::vector<vpImagePoint> &keyPoints, bool matches = true) const;
 
   /*!
     Get the list of Ransac inliers.
@@ -697,9 +703,7 @@ public:
                            vpImage<vpRGBa> &IMatching);
   void insertImageMatching(const vpImage<vpRGBa> &ICurrent, vpImage<vpRGBa> &IMatching);
 
-#ifdef VISP_HAVE_PUGIXML
   void loadConfigFile(const std::string &configFile);
-#endif
 
   void loadLearningData(const std::string &filename, bool binaryMode = false, bool append = false);
 
@@ -711,6 +715,7 @@ public:
                           unsigned int width);
   unsigned int matchPoint(const vpImage<unsigned char> &I, const vpRect &rectangle);
 
+  unsigned int matchPoint(const std::vector<cv::KeyPoint> &queryKeyPoints, const cv::Mat &queryDescriptors);
   bool matchPoint(const vpImage<unsigned char> &I, const vpCameraParameters &cam, vpHomogeneousMatrix &cMo,
                   bool (*func)(const vpHomogeneousMatrix &) = NULL, const vpRect &rectangle = vpRect());
   bool matchPoint(const vpImage<unsigned char> &I, const vpCameraParameters &cam, vpHomogeneousMatrix &cMo,
@@ -914,18 +919,28 @@ public:
     initMatcher(m_matcherName);
   }
 
+  /*!
+   * Set maximum number of keypoints to extract.
+   * \warning This functionality is only available for ORB and SIFT extactors.
+   * \param maxFeatures : Maximum number of keypoints to extract. Set -1 to use default values.
+   */
+  void setMaxFeatures(int maxFeatures)
+  {
+    m_maxFeatures = maxFeatures;
+  }
+
   /*!
     Set the filtering method to eliminate false matching.
     The different methods are:
-      - constantFactorDistanceThreshold (keep matches whose the descriptor
-    distance is below dist_min * factor)
-      - stdDistanceThreshold (keep matches whose the descriptor distance is
-    below dist_min + standard_deviation)
-      - ratioDistanceThreshold (keep matches enough discriminated: the ratio
-    distance between the 2 best matches is below the threshold)
-      - stdAndRatioDistanceThreshold (keep matches that agree with at least
-    one of the two conditions)
-      - noFilterMatching
+      - vpKeyPoint::constantFactorDistanceThreshold : Keep matches whose descriptor
+    distance is below dist_min * factor.
+      - vpKeyPoint::stdDistanceThreshold : Keep matches whose the descriptor distance is
+    below dist_min + standard_deviation.
+      - vpKeyPoint::ratioDistanceThreshold : Keep matches enough discriminated when the ratio
+    distance between the 2 best matches is below the threshold.
+      - vpKeyPoint::stdAndRatioDistanceThreshold : Keep matches that agree with at least
+    one of the two conditions.
+      - vpKeyPoint::noFilterMatching : No filter is applied.
 
     \param filterType : Type of the filtering method
   */
@@ -1300,6 +1315,8 @@ private:
   bool m_useSingleMatchFilter;
   //! Grayscale image buffer, used when passing color images
   vpImage<unsigned char> m_I;
+  //! Max number of features to extract, -1 to use default values
+  int m_maxFeatures;
 
   void affineSkew(double tilt, double phi, cv::Mat &img, cv::Mat &mask, cv::Mat &Ai);
 
