@@ -1,7 +1,7 @@
 /****************************************************************************
  *
- * This file is part of the ViSP software.
- * Copyright (C) 2005 - 2017 by Inria. All rights reserved.
+ * ViSP, open source Visual Servoing Platform software.
+ * Copyright (C) 2005 - 2019 by Inria. All rights reserved.
  *
  * This software is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -686,7 +686,7 @@ void vpHomography::computeDisplacement(const vpHomography &aHb, vpRotationMatrix
 #endif
 }
 
-void vpHomography::computeDisplacement(const vpHomography &H, const double x, const double y,
+void vpHomography::computeDisplacement(const vpHomography &H, double x, double y,
                                        std::list<vpRotationMatrix> &vR, std::list<vpTranslationVector> &vT,
                                        std::list<vpColVector> &vN)
 {
