@@ -446,7 +446,7 @@ void vpPoseFeatures::computePoseVVS(vpHomogeneousMatrix &cMo)
     vpMatrix L;
     vpColVector err;
     vpColVector v;
-
+    unsigned int rank_max = 0;
     unsigned int iter = 0;
 
     // while((int)((residu_1 - r)*1e12) != 0 )
@@ -461,14 +461,10 @@ void vpPoseFeatures::computePoseVVS(vpHomogeneousMatrix &cMo)
 
       // compute the pseudo inverse of the interaction matrix
       vpMatrix Lp;
-      unsigned int rank = L.pseudoInverse(Lp, 1e-16);
+      unsigned int rank = L.pseudoInverse(Lp, 1e-6);  // modif FC 1e-16
 
-      if (rank < 6) {
-        if (verbose)
-          vpTRACE("Rank must be at least 6 ! cMo not computed.");
-
-        break;
-      }
+      if (rank_max < rank)
+        rank_max = rank;
 
       // compute the VVS control law
       v = -lambda * Lp * err;
@@ -479,6 +475,11 @@ void vpPoseFeatures::computePoseVVS(vpHomogeneousMatrix &cMo)
         break;
       }
     }
+    if (rank_max < 6) {
+      if (verbose) {
+        vpTRACE("Only %d pose parameters can be estimated.", rank_max);
+      }
+    }
 
     if (computeCovariance)
       covarianceMatrix = vpMatrix::computeCovarianceMatrix(L, v, -lambda * err);
@@ -507,9 +508,10 @@ void vpPoseFeatures::computePoseRobustVVS(vpHomogeneousMatrix &cMo)
     vpColVector v;
     vpColVector error; // error vector
 
-    vpRobust robust(2 * totalSize);
-    robust.setThreshold(0.0000);
+    vpRobust robust;
+    robust.setMinMedianAbsoluteDeviation(0.00001);
 
+    unsigned int rank_max = 0;
     unsigned int iter = 0;
 
     // while((int)((residu_1 - r)*1e12) !=0)
@@ -532,7 +534,6 @@ void vpPoseFeatures::computePoseRobustVVS(vpHomogeneousMatrix &cMo)
       for (unsigned int k = 0; k < error.getRows() / 2; k++) {
         res[k] = vpMath::sqr(error[2 * k]) + vpMath::sqr(error[2 * k + 1]);
       }
-      robust.setIteration(0);
       robust.MEstimator(vpRobust::TUKEY, res, w);
 
       // compute the pseudo inverse of the interaction matrix
@@ -546,24 +547,25 @@ void vpPoseFeatures::computePoseRobustVVS(vpHomogeneousMatrix &cMo)
       (W * L).pseudoInverse(Lp, 1e-6);
       unsigned int rank = L.pseudoInverse(LRank, 1e-6);
 
-      if (rank < 6) {
-        if (verbose)
-          vpTRACE("Rank must be at least 6 ! cMo not computed.");
-
-        break;
-      }
+      if (rank_max < rank)
+        rank_max = rank;
 
       // compute the VVS control law
       v = -lambda * Lp * W * error;
 
       cMo = vpExponentialMap::direct(v).inverse() * cMo;
-      ;
       if (iter++ > vvsIterMax) {
         vpTRACE("Max iteration reached");
         break;
       }
     }
 
+    if (rank_max < 6) {
+      if (verbose) {
+        vpTRACE("Only %d pose parameters can be estimated.", rank_max);
+      }
+    }
+
     if (computeCovariance)
       covarianceMatrix =
           vpMatrix::computeCovarianceMatrix(L, v, -lambda * error, W * W); // Remark: W*W = W*W.t() since the
