@@ -76,11 +76,11 @@ public:
     \section Set coordinates
   */
   //! basic constructor
-  vpFeatureEllipse(double x, double y, double mu20, double mu11, double mu02);
+  vpFeatureEllipse(double x, double y, double n20, double n11, double n02);
 
   // void buildFrom(const vpEllipse &p) ;
-  void buildFrom(double x, double y, double mu20, double mu11, double mu02);
-  void buildFrom(double x, double y, double mu20, double mu11, double mu02,
+  void buildFrom(double x, double y, double n20, double n11, double n02);
+  void buildFrom(double x, double y, double n20, double n11, double n02,
                  double A, double B, double C);
 
   void display(const vpCameraParameters &cam, const vpImage<unsigned char> &I, const vpColor &color = vpColor::green,
@@ -96,11 +96,29 @@ public:
   //! compute the error between a visual features and zero
   vpColVector error(unsigned int select = FEATURE_ALL);
 
+  /*!
+   * Returns the visual feature corresponding to the ellipse centroid coordinate along camera x-axis.
+   */
   double get_x() const { return s[0]; }
+  /*!
+   * Returns the visual feature corresponding to the ellipse centroid coordinate along camera y-axis.
+   */
   double get_y() const { return s[1]; }
-  double getMu20() const { return s[2]; }
-  double getMu11() const { return s[3]; }
-  double getMu02() const { return s[4]; }
+  /*!
+   * Returns the visual feature corresponding to the second order centered moments
+   * of the ellipse normalized by its area \f$n_20 = mu_20/a\f$.
+   */
+  double get_n20() const { return s[2]; }
+  /*!
+   * Returns the visual feature corresponding to the second order centered moments
+   * of the ellipse normalized by its area \f$n_11 = mu_11/a\f$.
+   */
+  double get_n11() const { return s[3]; }
+  /*!
+   * Returns the visual feature corresponding to the second order centered moments
+   * of the ellipse normalized by its area \f$n_02 = mu_02/a\f$.
+   */
+  double get_n02() const { return s[4]; }
 
   //! Default initialization.
   void init();
@@ -114,9 +132,8 @@ public:
   void set_y(double y);
   void set_xy(double x, double y);
   void setABC(double A, double B, double C);
-  void setMu(double mu20, double mu11, double mu02);
+  void setMoments(double n20, double n11, double n02);
 
-public:
   /*!
     vpBasicFeature method instantiation
   */
@@ -124,9 +141,44 @@ public:
   // feature selection
   static unsigned int selectX();
   static unsigned int selectY();
-  static unsigned int selectMu20();
-  static unsigned int selectMu11();
-  static unsigned int selectMu02();
+  static unsigned int select_n20();
+  static unsigned int select_n11();
+  static unsigned int select_n02();
+
+#if defined(VISP_BUILD_DEPRECATED_FUNCTIONS)
+  /*!
+    @name Deprecated functions
+  */
+  //@{
+  vp_deprecated void setMu(double mu20, double mu11, double mu02);
+  vp_deprecated static unsigned int selectMu20();
+  vp_deprecated static unsigned int selectMu11();
+  vp_deprecated static unsigned int selectMu02();
+  /*!
+   * \deprecated You should rather use get_n20().
+   * This function is incorrectly named and is confusing since it
+   * returns the visual feature corresponding to the second order centered moments
+   * of the ellipse normalized by its area \f$n_20 = mu_20/a\f$.
+   */
+  vp_deprecated double getMu20() const { return s[2]; }
+  /*!
+   * \deprecated You should rather use get_n11().
+   * This function is incorrectly named and is confusing since it
+   * returns the visual feature corresponding to the second order centered moments
+   * of the ellipse normalized by its area \f$n_11 = mu_11/a\f$.
+   */
+  vp_deprecated double getMu11() const { return s[3]; }
+  /*!
+   * \deprecated You should rather use get_n02().
+   * This function is incorrectly named and is confusing since it
+   * returns the visual feature corresponding to the second order centered moments
+   * of the ellipse normalized by its area \f$n_02 = mu_02/a\f$.
+   */
+  vp_deprecated double getMu02() const { return s[4]; }
+
+  //@}
+#endif
+
 };
 
 #endif
