@@ -7,32 +7,7 @@
 #include <visp3/io/vpImageIo.h>
 #include <visp3/vision/vpPose.h>
 
-void computePose(std::vector<vpPoint> &point, const std::vector<vpImagePoint> &ip, const vpCameraParameters &cam,
-                 bool init, vpHomogeneousMatrix &cMo)
-{
-  vpPose pose;
-  double x = 0, y = 0;
-  for (unsigned int i = 0; i < point.size(); i++) {
-    vpPixelMeterConversion::convertPoint(cam, ip[i], x, y);
-    point[i].set_x(x);
-    point[i].set_y(y);
-    pose.addPoint(point[i]);
-  }
-
-  if (init == true) {
-    vpHomogeneousMatrix cMo_dem;
-    vpHomogeneousMatrix cMo_lag;
-    pose.computePose(vpPose::DEMENTHON, cMo_dem);
-    pose.computePose(vpPose::LAGRANGE, cMo_lag);
-    double residual_dem = pose.computeResidual(cMo_dem);
-    double residual_lag = pose.computeResidual(cMo_lag);
-    if (residual_dem < residual_lag)
-      cMo = cMo_dem;
-    else
-      cMo = cMo_lag;
-  }
-  pose.computePose(vpPose::VIRTUAL_VS, cMo);
-}
+#include "pose_helper.h"
 
 int main()
 {
@@ -54,13 +29,10 @@ int main()
 
     // 3D model of the QRcode: here we consider a 12cm by 12cm QRcode
     std::vector<vpPoint> point;
-    point.push_back(vpPoint(-0.06, -0.06,
-                            0)); // QCcode point 0 3D coordinates in plane Z=0
-    point.push_back(vpPoint(0.06, -0.06,
-                            0));             // QCcode point 1 3D coordinates in plane Z=0
-    point.push_back(vpPoint(0.06, 0.06, 0)); // QCcode point 2 3D coordinates in plane Z=0
-    point.push_back(vpPoint(-0.06, 0.06,
-                            0)); // QCcode point 3 3D coordinates in plane Z=0
+    point.push_back(vpPoint(-0.06, -0.06, 0)); // QRcode point 0 3D coordinates in plane Z=0
+    point.push_back(vpPoint( 0.06, -0.06, 0)); // QRcode point 1 3D coordinates in plane Z=0
+    point.push_back(vpPoint( 0.06,  0.06, 0)); // QRcode point 2 3D coordinates in plane Z=0
+    point.push_back(vpPoint(-0.06,  0.06, 0)); // QRcode point 3 3D coordinates in plane Z=0
 
     vpHomogeneousMatrix cMo;
     bool init = true;
@@ -89,8 +61,7 @@ int main()
             vpDisplay::displayText(I, p[j] + vpImagePoint(15, 5), number.str(), vpColor::blue);
           }
 
-          computePose(point, p, cam, init,
-                      cMo); // resulting pose is available in cMo var
+          computePose(point, p, cam, init, cMo); // resulting pose is available in cMo var
           std::cout << "Pose translation (meter): " << cMo.getTranslationVector().t() << std::endl
                     << "Pose rotation (quaternion): " << vpQuaternionVector(cMo.getRotationMatrix()).t() << std::endl;
           vpDisplay::displayFrame(I, cMo, cam, 0.05, vpColor::none, 3);
