@@ -13,13 +13,13 @@ int main(int argc, char **argv)
 #if (VISP_HAVE_OPENCV_VERSION >= 0x020400)
   //! [MBT code]
   try {
-    std::string videoname = "teabox.mpg";
+    std::string videoname = "teabox.mp4";
 
     for (int i = 0; i < argc; i++) {
       if (std::string(argv[i]) == "--name")
         videoname = std::string(argv[i + 1]);
-      else if (std::string(argv[i]) == "--help") {
-        std::cout << "\nUsage: " << argv[0] << " [--name <video name>] [--help]\n" << std::endl;
+      else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
+        std::cout << "\nUsage: " << argv[0] << " [--name <video name>] [--help] [-h]\n" << std::endl;
         return 0;
       }
     }
@@ -31,9 +31,7 @@ int main(int argc, char **argv)
 
     std::cout << "Video name: " << videoname << std::endl;
     std::cout << "Tracker requested config files: " << objectname << ".[init,"
-#ifdef VISP_HAVE_PUGIXML
               << "xml,"
-#endif
               << "cao or wrl]" << std::endl;
     std::cout << "Tracker optional config files: " << objectname << ".[ppm]" << std::endl;
 
@@ -60,13 +58,11 @@ int main(int argc, char **argv)
 
     vpMbGenericTracker tracker(vpMbGenericTracker::EDGE_TRACKER);
     bool usexml = false;
-#ifdef VISP_HAVE_PUGIXML
     if (vpIoTools::checkFilename(objectname + ".xml")) {
       tracker.loadConfigFile(objectname + ".xml");
       tracker.getCameraParameters(cam);
       usexml = true;
     }
-#endif
     if (!usexml) {
       vpMe me;
       me.setMaskSize(5);
@@ -98,7 +94,8 @@ int main(int argc, char **argv)
 //! [MBT code]
 
 //! [Keypoint selection]
-#if (defined(VISP_HAVE_OPENCV_NONFREE) || defined(VISP_HAVE_OPENCV_XFEATURES2D))
+#if (defined(VISP_HAVE_OPENCV_NONFREE) || defined(VISP_HAVE_OPENCV_XFEATURES2D)) || \
+    (VISP_HAVE_OPENCV_VERSION >= 0x030411 && CV_MAJOR_VERSION < 4) || (VISP_HAVE_OPENCV_VERSION >= 0x040400)
     std::string detectorName = "SIFT";
     std::string extractorName = "SIFT";
     std::string matcherName = "BruteForce";
@@ -116,9 +113,7 @@ int main(int argc, char **argv)
     //! [Keypoint declaration]
     if (usexml) {
 //! [Keypoint xml config]
-#ifdef VISP_HAVE_PUGIXML
       keypoint_learning.loadConfigFile(configurationFile);
-#endif
       //! [Keypoint xml config]
     } else {
       //! [Keypoint code config]
@@ -168,9 +163,7 @@ int main(int argc, char **argv)
     //! [Init keypoint detection]
     vpKeyPoint keypoint_detection;
     if (usexml) {
-#ifdef VISP_HAVE_PUGIXML
       keypoint_detection.loadConfigFile(configurationFile);
-#endif
     } else {
       keypoint_detection.setDetector(detectorName);
       keypoint_detection.setExtractor(extractorName);
@@ -220,9 +213,6 @@ int main(int argc, char **argv)
     }
     if (!click_done)
       vpDisplay::getClick(I);
-#if defined(VISP_HAVE_COIN3D) && (COIN_MAJOR_VERSION >= 2)
-    SoDB::finish();
-#endif
   } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
