@@ -4,8 +4,7 @@
 #include <visp3/gui/vpDisplayOpenCV.h>
 #include <visp3/gui/vpDisplayX.h>
 #include <visp3/sensor/vpPylonFactory.h>
-
-#include "record_helper.h"
+#include <visp3/io/vpImageStorageWorker.h>
 
 /*!
   Usage :
@@ -14,7 +13,7 @@
  */
 int main(int argc, const char *argv[])
 {
-#ifdef VISP_HAVE_PYLON
+#if defined(VISP_HAVE_PYLON) && (VISP_CXX_STANDARD >= VISP_CXX_STANDARD_11)
   try {
     unsigned int opt_camera = 0;
     std::string opt_device("GigE");
@@ -36,8 +35,8 @@ int main(int argc, const char *argv[])
       else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "-h") {
         std::cout << "\nUsage: " << argv[0]
                   << " [--camera <0...9> (default: 0)] [--device <\"GigE\"|\"USB\" (default: GigE)>]"
-                  << " [--seqname <sequence name (default: empty>] [--record <0: continuous | 1: single shot (default: 0)>]"
-                  <<  " [--change_settings] [--help] [-h]\n"
+                  << " [--seqname <sequence name (default: empty)>] [--record <0: continuous | 1: single shot (default: 0)>]"
+                  << " [--change_settings] [--help] [-h]\n"
                   << "\nExample to visualize images:\n"
                   << "  " << argv[0] << " \n"
                   << "  " << argv[0] << " --device GigE --camera 0\n"
@@ -93,6 +92,10 @@ int main(int argc, const char *argv[])
     std::cout << "No image viewer is available..." << std::endl;
 #endif
 
+    vpImageQueue<unsigned char> image_queue(opt_seqname, opt_record_mode);
+    vpImageStorageWorker<unsigned char> image_storage_worker(std::ref(image_queue));
+    std::thread image_storage_thread(&vpImageStorageWorker<unsigned char>::run, &image_storage_worker);
+
     bool quit = false;
     while (! quit) {
       double t = vpTime::measureTimeMs();
@@ -100,19 +103,26 @@ int main(int argc, const char *argv[])
 
       vpDisplay::display(I);
 
-      quit = record_helper(opt_seqname, opt_record_mode, I);
+      quit = image_queue.record(I);
 
       std::stringstream ss;
       ss << "Acquisition time: " << std::setprecision(3) << vpTime::measureTimeMs() - t << " ms";
       vpDisplay::displayText(I, I.getHeight() - 20, 10, ss.str(), vpColor::red);
       vpDisplay::flush(I);
     }
+    image_queue.cancel();
+    image_storage_thread.join();
   } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 #else
   (void) argc;
   (void) argv;
+#ifndef VISP_HAVE_PYLON
   std::cout << "Install Basler Pylon SDK, configure and build ViSP again to use this example" << std::endl;
 #endif
+#if (VISP_CXX_STANDARD < VISP_CXX_STANDARD_11)
+  std::cout << "This turorial should be built with c++11 support" << std::endl;
+#endif
+#endif
 }
