@@ -121,14 +121,14 @@ int main(int argc, const char *argv[])
 
   // Command line options
   for (int i = 0; i < argc; i++) {
-    if (std::string(argv[i]) == "--device")
+    if (std::string(argv[i]) == "--camera_device")
       opt_device = (unsigned int)atoi(argv[i + 1]);
     else if (std::string(argv[i]) == "--scale")
       opt_scale = (unsigned int)atoi(argv[i + 1]);
-    else if (std::string(argv[i]) == "--help") {
+    else if (std::string(argv[i]) == "--help" || std::string(argv[i]) == "--h") {
       std::cout << "Usage: " << argv[0]
-                << " [--device <camera device>] [--scale <subsampling "
-                   "factor>] [--help]"
+                << " [--camera_device <camera device (default: 0)>] [--scale <subsampling factor>]"
+                << " [--help] [-h]"
                 << std::endl;
       return 0;
     }
