@@ -7,12 +7,16 @@ int main()
 #if defined(VISP_HAVE_OPENCV) && (VISP_HAVE_OPENCV_VERSION >= 0x020100)
   try {
     cv::Mat A;
-#if (VISP_HAVE_OPENCV_VERSION >= 0x030000)
-    A = cv::imread("monkey.bmp", cv::IMREAD_GRAYSCALE);
-#else
-    A = cv::imread("monkey.bmp", CV_LOAD_IMAGE_GRAYSCALE);
+#if VISP_HAVE_OPENCV_VERSION >= 0x030200
+    int flags = cv::IMREAD_GRAYSCALE | cv::IMREAD_IGNORE_ORIENTATION;
+#elif VISP_HAVE_OPENCV_VERSION >= 0x030000
+    int flags = cv::IMREAD_GRAYSCALE;
+#elif VISP_HAVE_OPENCV_VERSION >= 0x020100
+    int flags = CV_LOAD_IMAGE_GRAYSCALE;
 #endif
 
+    A = cv::imread("monkey.bmp", flags);
+
     vpImage<unsigned char> I;
     vpImageConvert::convert(A, I);
 
