@@ -97,7 +97,7 @@ int main()
 
       vpTime::wait(40);
     }
-  } catch (vpException &e) {
+  } catch (const vpException &e) {
     std::cout << "Catch an exception: " << e << std::endl;
   }
 }
