@@ -4,14 +4,15 @@
 #include <visp3/sensor/vp1394CMUGrabber.h>
 #include <visp3/sensor/vp1394TwoGrabber.h>
 #endif
+#include <visp3/blob/vpDot2.h>
 #include <visp3/gui/vpDisplayGDI.h>
 #include <visp3/gui/vpDisplayOpenCV.h>
 #include <visp3/gui/vpDisplayX.h>
-#include <visp3/blob/vpDot2.h>
 
 int main()
 {
-#if (defined(VISP_HAVE_DC1394) || defined(VISP_HAVE_CMU1394) || (VISP_HAVE_OPENCV_VERSION >= 0x020100)) && (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV))
+#if (defined(VISP_HAVE_DC1394) || defined(VISP_HAVE_CMU1394) || (VISP_HAVE_OPENCV_VERSION >= 0x020100)) &&             \
+    (defined(VISP_HAVE_X11) || defined(VISP_HAVE_GDI) || defined(VISP_HAVE_OPENCV))
   vpImage<unsigned char> I; // Create a gray level image container
 
 #if defined(VISP_HAVE_DC1394)
@@ -22,7 +23,7 @@ int main()
   g.open(I);
 #elif defined(VISP_HAVE_OPENCV)
   cv::VideoCapture g(0); // open the default camera
-  if(!g.isOpened()) { // check if we succeeded
+  if (!g.isOpened()) {   // check if we succeeded
     std::cout << "Failed to open the camera" << std::endl;
     return -1;
   }
@@ -50,7 +51,7 @@ int main()
   vpImagePoint germ;
   bool init_done = false;
 
-  while(1) {
+  while (1) {
     try {
 #if defined(VISP_HAVE_DC1394) || defined(VISP_HAVE_CMU1394)
       g.acquire(I);
@@ -60,24 +61,22 @@ int main()
 #endif
       vpDisplay::display(I);
 
-      if (! init_done) {
-        vpDisplay::displayText(I, vpImagePoint(10,10), "Click in the blob to initialize the tracker", vpColor::red);
+      if (!init_done) {
+        vpDisplay::displayText(I, vpImagePoint(10, 10), "Click in the blob to initialize the tracker", vpColor::red);
         if (vpDisplay::getClick(I, germ, false)) {
           //! [Init]
           blob.initTracking(I, germ);
           //! [Init]
           init_done = true;
         }
-      }
-      else {
+      } else {
         //! [Track]
         blob.track(I);
         //! [Track]
       }
 
       vpDisplay::flush(I);
-    }
-    catch(...) {
+    } catch (...) {
       init_done = false;
     }
   }
