@@ -81,12 +81,12 @@ int main()
       if ((task.getError()).sumSquare() < 0.0001)
         break;
 
+      vpTime::wait(100);
+
       iter++;
     }
     std::cout << "Convergence in " << iter << " iterations" << std::endl;
 
-    task.kill();
-
 #ifdef VISP_HAVE_DISPLAY
     plotter.saveData(0, "error.dat");
     plotter.saveData(1, "vc.dat");
